@@ -13,7 +13,7 @@
  *           where apbs.in is a formatted input file (see documentation and
  *           examples).
  * 
- *  @version $Id: main.c 1109 2007-07-12 15:51:25Z sdg0919 $
+ *  @version $Id: main.c 1260 2008-04-15 18:40:45Z yhuang01 $
  *  @attention
  *  @verbatim
  *
@@ -26,50 +26,39 @@
  *
  * Additional contributing authors listed in the code documentation.
  *
- * Copyright (c) 2002-2007.  Washington University in St. Louis.
- * All Rights Reserved.
- * Portions Copyright (c) 1999-2002.  The Regents of the University of
- * California.  
- * Portions Copyright (c) 1995.  Michael Holst.
+ * Copyright (c) 2002-2008, Washington University in St. Louis.
+ * Portions Copyright (c) 2002-2008.  Nathan A. Baker
+ * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
+ * Portions Copyright (c) 1995.  Michael Holst
  *
- * This file is part of APBS.
- *
- * APBS is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * APBS is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with APBS; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
- *
- * Linking APBS statically or dynamically with other modules is making a
- * combined work based on APBS. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
+ * All rights reserved.
  * 
- * SPECIAL GPL EXCEPTION
- * In addition, as a special exception, the copyright holders of APBS
- * give you permission to combine the APBS program with free software
- * programs and libraries that are released under the GNU LGPL or with
- * code included in releases of ISIM, Ion Simulator Interface, PMV, PyMOL
- * SMOL, VMD, and Vision. Such combined software may be linked with APBS and 
- * redistributed together in original or modified form as mere aggregation
- * without requirement that the entire work be under the scope of the GNU 
- * General Public License. This special exception permission is also extended
- * to any software listed in the SPECIAL GPL EXCEPTION clauses by the PMG,
- * FEtk, MC, or MALOC libraries.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met: 
+ *
+ * -  Redistributions of source code must retain the above copyright notice, this
+ * list of conditions and the following disclaimer.  
+ * 
+ * - Redistributions in binary form must reproduce the above copyright notice,
+ * this list of conditions and the following disclaimer in the documentation
+ * and/or other materials provided with the distribution.
+ * 
+ * - Neither the name of Washington University in St. Louis nor the names of its
+ * contributors may be used to endorse or promote products derived from this
+ * software without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
+ * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
+ * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+ * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+ * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * Note that people who make modified versions of APBS are not obligated
- * to grant this special exception for their modified versions; it is
- * their choice whether to do so. The GNU General Public License gives
- * permission to release a modified version without this exception; this
- * exception also makes it possible to release a modified version which
- * carries forward this exception.
  *
  * @endverbatim
  */
@@ -83,7 +72,7 @@
 
 #include "routines.h"
 
-VEMBED(rcsid="$Id: main.c 1109 2007-07-12 15:51:25Z sdg0919 $")
+VEMBED(rcsid="$Id: main.c 1260 2008-04-15 18:40:45Z yhuang01 $")
 
 int main(
 		 int argc, 
@@ -104,8 +93,10 @@ int main(
 	Vio *sock = VNULL;
 #ifdef HAVE_MC_H
 	Vfetk *fetk[NOSH_MAXCALC];
+	Gem *gm[NOSH_MAXMOL];
 #else
 	void *fetk[NOSH_MAXCALC];
+	void *gm[NOSH_MAXMOL];
 #endif
 	Vpmg *pmg[NOSH_MAXCALC];
 	Vpmgp *pmgp[NOSH_MAXCALC];
@@ -117,7 +108,7 @@ int main(
 	char *input_path = VNULL;
 	char *output_path = VNULL;
 	int i, rank, size, isolve, k;
-	unsigned long int bytesTotal, highWater;
+	size_t bytesTotal, highWater;
 	Voutput_Format outputformat;
 	
 	int rc = 0;
@@ -143,7 +134,7 @@ int main(
 	char header[] = {"\n\n\
 ----------------------------------------------------------------------\n\
 	APBS -- Adaptive Poisson-Boltzmann Solver\n\
-	Version 0.5.1\n\
+	Version 1.0.0\n\
 	\n\
 	Nathan A. Baker (baker@biochem.wustl.edu)\n\
 	Dept. Biochemistry and Molecular Biophysics\n\
@@ -152,58 +143,55 @@ int main(
 	\n\
 	Additional contributing authors listed in the code documentation.\n\
 	\n\
-	Copyright (c) 2002-2007.  Washington University in St. Louis.\n\
-	All Rights Reserved.\n\
-	Portions Copyright (c) 1999-2002.  The Regents of the University of \n\
-	California.\n\
-	Portions Copyright (c) 1995.  Michael Holst.\n\
+	Copyright (c) 2002-2008, Washington University in St. Louis.\n\
+	Portions Copyright (c) 2002-2008.  Nathan A. Baker\n\
+	Portions Copyright (c) 1999-2002.  The Regents of the University of California.\n\
+	Portions Copyright (c) 1995.  Michael Holst\n\
 	\n\
-	This program is free software; you can redistribute it and/or modify\n\
-	it under the terms of the GNU General Public License as published by\n\
-	the Free Software Foundation; either version 2 of the License, or\n\
-	(at your option) any later version.\n\
+	All rights reserved.\n\
 	\n\
-	This program is distributed in the hope that it will be useful,\n\
-	but WITHOUT ANY WARRANTY; without even the implied warranty of\n\
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n\
-	GNU General Public License for more details.\n\
+	Redistribution and use in source and binary forms, with or without\n\
+	modification, are permitted provided that the following conditions are met: \n\
 	\n\
-	You should have received a copy of the GNU General Public License\n\
-	along with this program; if not, write to the Free Software\n\
-	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA\n\
+	* Redistributions of source code must retain the above copyright notice, this\n\
+	list of conditions and the following disclaimer.  \n\
 	\n\
-	Linking APBS statically or dynamically with other modules is making a\n\
-	combined work based on APBS. Thus, the terms and conditions of the GNU\n\
-	General Public License cover the whole combination.\n\
+	* Redistributions in binary form must reproduce the above copyright notice,\n\
+	this list of conditions and the following disclaimer in the documentation\n\
+	and/or other materials provided with the distribution.\n\
 	\n\
-	SPECIAL GPL EXCEPTION\n\
-	In addition, as a special exception, the copyright holders of APBS\n\
-	give you permission to combine the APBS program with free software\n\
-	programs and libraries that are released under the GNU LGPL or with\n\
-	code included in releases of ISIM, Ion Simulator Interface, PMV,\n\
-	SMOL, VMD, and Vision. Such combined software may be linked with APBS and\n\
-	redistributed together in original or modified form as mere aggregation\n\
-	without requirement that the entire work be under the scope of the GNU\n\
-	General Public License. This special exception permission is also extended\n\
-	to any software listed in the SPECIAL GPL EXCEPTION clauses by the PMG,\n\
-	FEtk, MC, or MALOC libraries.\n\
+	* Neither the name of Washington University in St. Louis nor the names of its\n\
+	contributors may be used to endorse or promote products derived from this\n\
+	software without specific prior written permission.\n\
 	\n\
-	Note that people who make modified versions of APBS are not obligated\n\
-	to grant this special exception for their modified versions; it is\n\
-	their choice whether to do so. The GNU General Public License gives\n\
-	permission to release a modified version without this exception; this\n\
-	exception also makes it possible to release a modified version which\n\
-	carries forward this exception.\n\
+	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS\n\
+	\"AS IS\" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT\n\
+	LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR\n\
+	A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR\n\
+	CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,\n\
+	EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,\n\
+	PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR\n\
+	PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF\n\
+	LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING\n\
+	NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS\n\
+	SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.\n\
 ----------------------------------------------------------------------\n\
 	APBS uses FETK (the Finite Element ToolKit) to solve the\n\
 	Poisson-Boltzmann equation numerically.  FETK is a portable collection\n\
-	of finite element modeling class libraries written in an object-oriented\n\
-	version of C.  It is designed to solve general coupled systems of nonlinear\n\
-	partial differential equations using adaptive finite element methods,\n\
-	inexact Newton methods, and algebraic multilevel methods.  More information\n\
-	about FEtk may be found at <http://www.FEtk.ORG>.\n\
+	of finite element modeling class libraries developed by the Michael Holst\n\
+	research group and written in an object-oriented form of C.  FEtk is\n\
+	designed to solve general coupled systems of nonlinear partial differential\n\
+	equations using adaptive finite element methods, inexact Newton methods,\n\
+	and algebraic multilevel methods.  More information about FEtk may be found\n\
+	at <http://www.FEtk.ORG>.\n\
 ----------------------------------------------------------------------\n\
-Please cite your use of APBS as:\n\n\
+	APBS also uses Aqua to solve the Poisson-Boltzmann equation numerically.  \n\
+	Aqua is a modified form of the Holst group PMG library <http://www.FEtk.ORG>\n\
+	which has been modified by Patrice Koehl\n\
+	<http://koehllab.genomecenter.ucdavis.edu/> for improved efficiency and\n\
+	memory usage when solving the Poisson-Boltzmann equation.\n\
+----------------------------------------------------------------------\n\
+	Please cite your use of APBS as:\n\n\
 	Baker NA, Sept D, Joseph S, Holst MJ, McCammon JA. Electrostatics of\n\
 	nanosystems: application to microtubules and the ribosome. Proc.\n\
 	Natl. Acad. Sci. USA 98, 10037-10041 2001.\n\
@@ -225,7 +213,6 @@ Please cite your use of APBS as:\n\n\
 --version                Display the current APBS version.\n\
 ----------------------------------------------------------------------\n\n"};
 
-
 	/* ************** CHECK PARALLEL STATUS *************** */
 	VASSERT(Vcom_init(&argc, &argv));
 	com = Vcom_ctor(1);
@@ -262,6 +249,14 @@ Please cite your use of APBS as:\n\n\
 	/* ********* CHECK INVOCATION AND OPTIONS ************* */
 	Vnm_tstart(APBS_TIMER_WALL_CLOCK, "APBS WALL CLOCK");
 	Vnm_tprint( 1, "%s", header);
+
+#ifdef APBS_FAST
+	printf("WARNING: APBS was compiled with the --enable-fast option.\n"
+		   "WARNING: This mode is experimental and subject to change in future releases.\n"
+		   "WARNING: The fast mode enables: Gauess-Seidel Smoothing and \n"
+		   "WARNING:   Conjugate Gradient Multigrid methods.\n\n");
+#endif
+
 	Vnm_tprint( 1, "This executable compiled on %s at %s\n\n", __DATE__, __TIME__);
 
 	i=0;
@@ -324,15 +319,19 @@ Please cite your use of APBS as:\n\n\
 
 	/* *************** PARSE INPUT FILE ******************* */
 	nosh = NOsh_ctor(rank, size);
-	sock = Vio_ctor("FILE", "ASC", VNULL, input_path, "r");
 	Vnm_tprint( 1, "Parsing input file %s...\n", input_path);
+	sock = Vio_ctor("FILE", "ASC", VNULL, input_path, "r");
+	if (sock == VNULL) {
+		Vnm_tprint(2, "Error while opening input file %s!\n", input_path);
+		VJMPERR1(0);
+	}
 	if (!NOsh_parseInput(nosh, sock)) {
 		Vnm_tprint( 2, "Error while parsing input file.\n");
 		VJMPERR1(0);
 	} else Vnm_tprint( 1, "Parsed input file.\n");
 	Vio_dtor(&sock);
-
-	/* *************** LOAD PARAMETERS AND MOLECULES ******************* */
+	
+	/* *************** LOAD PARAMETERS AND MOLECULES ******************* */	
 	param = loadParameter(nosh);
 	if (loadMolecules(nosh, param, alist) != 1) {
 		Vnm_tprint(2, "Error reading molecules!\n");
@@ -351,11 +350,11 @@ Please cite your use of APBS as:\n\n\
 	}
 	
 	/* ******************* CHECK APOL********************** */
-	if((nosh->gotparm == 0) && (rc == ACD_YES)){
-		Vnm_print(1,"\nError you must provide a parameter file if you\n" \
-					"     are performing an APOLAR calculation\n");
-		VJMPERR1(0);
-	}
+	/* if((nosh->gotparm == 0) && (rc == ACD_YES)){
+	 	Vnm_print(1,"\nError you must provide a parameter file if you\n" \
+	 				"     are performing an APOLAR calculation\n");
+	 	VJMPERR1(0);
+	} */
 
 	/* *************** LOAD MAPS ******************* */
 	if (loadDielMaps(nosh, dielXMap, dielYMap, dielZMap) != 1) {
@@ -370,7 +369,7 @@ Please cite your use of APBS as:\n\n\
 		Vnm_tprint(2, "Error reading charge maps!\n");
 		VJMPERR1(0);
 	}
-
+	
 	/* *************** DO THE CALCULATIONS ******************* */
 	Vnm_tprint( 1, "Preparing to run %d PBE calculations.\n",
 				nosh->ncalc);
@@ -404,7 +403,7 @@ Please cite your use of APBS as:\n\n\
 					Vnm_tprint( 2, "Error setting up MG calculation!\n");
 					VJMPERR1(0);
 				}
-					
+				
 				/* Print problem parameters */
 				printMGPARM(mgparm, realCenter);
 				printPBEPARM(pbeparm);
@@ -470,7 +469,7 @@ Please cite your use of APBS as:\n\n\
 				
 				/* Set up problem */
 				Vnm_tprint( 1, "  Setting up problem...\n");
-				if (!initFE(i, nosh, feparm, pbeparm, pbe, alist, fetk)) {
+				if (initFE(i, nosh, feparm, pbeparm, pbe, alist, fetk, gm) != VRC_SUCCESS) {
 					Vnm_tprint( 2, "Error setting up FE calculation!\n");
 					VJMPERR1(0);
 				}
@@ -559,7 +558,10 @@ Please cite your use of APBS as:\n\n\
 				exit(2);
 		}
 	}
-
+	
+	//Clear out the parameter file memory
+	if(param != VNULL) Vparam_dtor(&param);
+	
 	/* *************** HANDLE PRINT STATEMENTS ******************* */
 	if (nosh->nprint > 0) {
 		Vnm_tprint( 1, "----------------------------------------\n");
@@ -586,7 +588,7 @@ Please cite your use of APBS as:\n\n\
 		}
 	} 
 	Vnm_tprint( 1, "----------------------------------------\n");
-
+	
 	/* *************** HANDLE LOGGING *********************** */
 
 	if (outputformat == OUTPUT_XML) {
@@ -614,6 +616,9 @@ Please cite your use of APBS as:\n\n\
 	killForce(mem, nosh, nforce, atomForce);
 	killEnergy();
 	killMG(nosh, pbe, pmgp, pmg);
+#ifdef HAVE_MC_H
+	killFE(nosh, pbe, fetk, gm);
+#endif
 	killChargeMaps(nosh, chargeMap);
 	killKappaMaps(nosh, kappaMap);
 	killDielMaps(nosh, dielXMap, dielYMap, dielZMap);
@@ -640,9 +645,9 @@ Please cite your use of APBS as:\n\n\
 	Vnm_flush(1);
 	Vnm_flush(2);
 	Vcom_finalize();
-	
-	fflush(NULL);
 
+	fflush(NULL);
+	
 	return 0;
 
 	VERROR1:
