@@ -7,7 +7,7 @@
  *  @author  Nathan Baker
  *  @brief   Header file for front end auxiliary routines
  *  @ingroup  Frontend
- *  @version $Id: routines.h 1098 2007-06-13 15:50:28Z sobolevnrm $
+ *  @version $Id: routines.h 1251 2008-03-30 22:32:00Z sobolevnrm $
  *  @attention
  *  @verbatim
  *
@@ -20,50 +20,38 @@
  *
  * Additional contributing authors listed in the code documentation.
  *
- * Copyright (c) 2002-2007.  Washington University in St. Louis.
- * All Rights Reserved.
- * Portions Copyright (c) 1999-2002.  The Regents of the University of
- * California.  
- * Portions Copyright (c) 1995.  Michael Holst.
+ * Copyright (c) 2002-2008, Washington University in St. Louis.
+ * Portions Copyright (c) 2002-2008.  Nathan A. Baker
+ * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
+ * Portions Copyright (c) 1995.  Michael Holst
  *
- * This file is part of APBS.
- *
- * APBS is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * APBS is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with APBS; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
- *
- * Linking APBS statically or dynamically with other modules is making a
- * combined work based on APBS. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
+ * All rights reserved.
  * 
- * SPECIAL GPL EXCEPTION
- * In addition, as a special exception, the copyright holders of APBS
- * give you permission to combine the APBS program with free software
- * programs and libraries that are released under the GNU LGPL or with
- * code included in releases of ISIM, Ion Simulator Interface, PMV, PyMOL
- * SMOL, VMD, and Vision. Such combined software may be linked with APBS and 
- * redistributed together in original or modified form as mere aggregation
- * without requirement that the entire work be under the scope of the GNU 
- * General Public License. This special exception permission is also extended
- * to any software listed in the SPECIAL GPL EXCEPTION clauses by the PMG,
- * FEtk, MC, or MALOC libraries.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met: 
+ *
+ * -  Redistributions of source code must retain the above copyright notice, this
+ * list of conditions and the following disclaimer.  
  * 
- * Note that people who make modified versions of APBS are not obligated
- * to grant this special exception for their modified versions; it is
- * their choice whether to do so. The GNU General Public License gives
- * permission to release a modified version without this exception; this
- * exception also makes it possible to release a modified version which
- * carries forward this exception.
+ * - Redistributions in binary form must reproduce the above copyright notice,
+ * this list of conditions and the following disclaimer in the documentation
+ * and/or other materials provided with the distribution.
+ * 
+ * - Neither the name of Washington University in St. Louis nor the names of its
+ * contributors may be used to endorse or promote products derived from this
+ * software without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
+ * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
+ * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+ * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+ * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * @endverbatim
  */
@@ -232,12 +220,13 @@ VEXTERNC int initMG(
  * @brief  Kill structures initialized during an MG calculation
  * @ingroup  Frontend
  * @author  Nathan Baker
- * @param nosh  Object with parsed input file parameters
- * @param pbe  Array of Vpbe objects (one for each calc)
- * @param pmgp  Array of MG parameter objects (one for each calc)
- * @param pmg  Array of MG objects (one for each calc) */
-VEXTERNC void killMG(NOsh *nosh, Vpbe *pbe[NOSH_MAXCALC],
-  Vpmgp *pmgp[NOSH_MAXCALC], Vpmg *pmg[NOSH_MAXCALC]);
+ */
+VEXTERNC void killMG(
+					 NOsh *nosh,  /** Object with parsed input file parameters */
+					 Vpbe *pbe[NOSH_MAXCALC],  /** Array of Vpbe objects for each calc */
+					 Vpmgp *pmgp[NOSH_MAXCALC],  /** Array of MG parameter objects for each calc */
+					 Vpmg *pmg[NOSH_MAXCALC]  /** Array of MG objects for each calc */
+);
 
 /**
  * @brief  Solve the PBE with MG
@@ -479,6 +468,8 @@ VEXTERNC int printApolForce(
 VEXTERNC void startVio();
 
 #ifdef HAVE_MC_H
+#include "apbs/vfetk.h"
+
 /**
  * @brief  Print out FE-specific params loaded from input
  * @ingroup  Frontend
@@ -512,19 +503,32 @@ VEXTERNC int energyFE(NOsh* nosh, int icalc, Vfetk *fetk[NOSH_MAXCALC],
  * @brief  Initialize FE solver objects
  * @ingroup  Frontend
  * @author  Nathan Baker
- * @param  icalc  Index in pbe, fetk to initialize -- calculation index
- * @param nosh  Master parameter object
- * @param feparm  FE-specific parameters 
- * @param pbeparm  Generic PBE parameters
- * @param pbe  Array of PBE objects 
- * @param alist Array of atom lists 
- * @param fetk  Array of FE solver objects 
  * @bug  THIS FUNCTION IS HARD-CODED TO SOLVE LRPBE
  * @todo  THIS FUNCTION IS HARD-CODED TO SOLVE LRPBE
- * @return  1 if successful, 0 otherwise */
-VEXTERNC int initFE(int icalc, NOsh *nosh, FEMparm *feparm, PBEparm *pbeparm,
-  Vpbe *pbe[NOSH_MAXCALC], Valist *alist[NOSH_MAXMOL], 
-  Vfetk *fetk[NOSH_MAXCALC]);
+ */
+VEXTERNC Vrc_Codes initFE(
+					int icalc, /** Index in pb, fetk to initialize (calculation 
+ index) */
+					NOsh *nosh,  /** Master parmaeter object */
+					FEMparm *feparm,  /** FE-specific parameters */
+					PBEparm *pbeparm,  /** Generic PBE parameters */
+					Vpbe *pbe[NOSH_MAXCALC],  /** Array of PBE objects */
+					Valist *alist[NOSH_MAXMOL],  /** Array of atom lists */
+					Vfetk *fetk[NOSH_MAXCALC],  /** Array of finite element objects */
+					Gem *gm[NOSH_MAXCALC]  /** Array of geometry objects */
+);
+
+/**
+ * @brief  Kill structures initialized during an FE calculation
+ * @ingroup  Frontend
+ * @author  Nathan Baker
+ */
+VEXTERNC void killFE(
+					 NOsh *nosh,  /** Object with parsed input file parameters */
+					 Vpbe *pbe[NOSH_MAXCALC],  /** Array of Vpbe objects for each calc */
+					 Vfetk *fetk[NOSH_MAXCALC],  /** Array of FEtk objects for each calc */
+					 Gem *gem[NOSH_MAXMOL]  /** Array of geometry manager objects for each calc */
+);
 
 /**
  * @brief  Pre-refine mesh before solve
@@ -597,7 +601,10 @@ VEXTERNC int writedataFE(int rank, NOsh *nosh, PBEparm *pbeparm, Vfetk *fetk);
 VEXTERNC int energyAPOL(
 						APOLparm *apolparm, /** APOLparm object */
 						double sasa, /** Solvent accessible surface area */
-						double sav /** Solvent accessible volume */
+						double sav, /** Solvent accessible volume */
+						double atomsasa[], /** Array for SASA per atom **/
+						double atomwcaEnergy[], /** Array for WCA energy per atom **/
+						int numatoms /** Number of atoms (or size of the above arrays) **/
 						);
 
 /**
@@ -633,6 +640,25 @@ VEXTERNC int initAPOL(
 					  Valist *alist  /**< Atom list */
 					  );
 
+/**
+ * @brief  Load the meshes given in NOsh into geometry objects
+ * @ingroup  Frontend
+ * @author  Nathan Baker
+ * @returns  Error code on success/failure */
+VEXTERNC Vrc_Codes loadMeshes(
+							NOsh *nosh, /**< NOsh object with input file information */
+							Gem *gm[NOSH_MAXMOL]  /**< List of geometry objects
+							(to be populated) */
+						   );
+						
+/**
+ * @brief  Destroy the loaded meshes
+ * @ingroup  Frontend
+ * @author  Nathan Baker */
+VEXTERNC void killMeshes(
+							NOsh *nosh, /**< NOsh object with input file information */
+							Gem *alist[NOSH_MAXMOL]  /**< Populated list of geometry objects to be destroyed */
+							);
 #endif
 
 #endif
