@@ -1,23 +1,23 @@
 /*
  * ***************************************************************************
  * MALOC = < Minimal Abstraction Layer for Object-oriented C >
- * Copyright (C) 1994--2000  Michael Holst
- * 
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 2 of the License, or (at your
- * option) any later version.
- * 
- * This program is distributed in the hope that it will be useful,
+ * Copyright (C) 1994--2008 Michael Holst
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 675 Mass Ave, Cambridge, MA 02139, USA.
- * 
- * rcsid="$Id: vio.c,v 1.28 2004/02/18 01:10:56 mholst Exp $"
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ *
+ * rcsid="$Id: vio.c,v 1.31 2008/03/12 05:13:59 fetk Exp $"
  * ***************************************************************************
  */
 
@@ -33,7 +33,7 @@
 
 #include "vio_p.h"
 
-VEMBED(rcsid="$Id: vio.c,v 1.28 2004/02/18 01:10:56 mholst Exp $")
+VEMBED(rcsid="$Id: vio.c,v 1.31 2008/03/12 05:13:59 fetk Exp $")
 
 #if defined(HAVE_UNISTD_H)
 #   include <unistd.h>
@@ -326,7 +326,7 @@ VPRIVATE int VIOgethostname(char *name, unsigned int len)
  */
 VPRIVATE const char *VIOstrerrno(int err)
 {
-    static char errstr[80];
+    static char errstr[VMAX_ARGLEN];
 
     if      (err == EFAULT           ) strcpy(errstr,"EFAULT");
     else if (err == EINTR            ) strcpy(errstr,"EINTR");
@@ -427,7 +427,7 @@ VPUBLIC int Vio_ctor2(Vio *thee, const char *socktype, const char *datafrmt,
     const char *hostname, const char *filename, const char *rwkey)
 {
     int n, ival;
-    char host[80];
+    char host[VMAX_ARGLEN];
     struct linger ling;
     unsigned int len;
     struct hostent *hpTmp;
@@ -435,7 +435,7 @@ VPUBLIC int Vio_ctor2(Vio *thee, const char *socktype, const char *datafrmt,
     WSADATA wsaData;
 #endif
 #if defined(HAVE_SYS_UN_H)
-    char username[80];
+    char username[VMAX_ARGLEN];
 #endif
 
     /* make sure Vio was started */
@@ -536,7 +536,12 @@ VPUBLIC int Vio_ctor2(Vio *thee, const char *socktype, const char *datafrmt,
     } else if (thee->type==VIO_FILE) {
 
         /* filename is the i/o file name */
-        strncpy(thee->file, filename, 80);
+        if (strlen(filename) >= VMAX_ARGLEN) {
+            fprintf(stderr, "Vio_ctor2: Filename <%d> exceeds max <%d>!\n",
+                (int)strlen(filename), VMAX_ARGLEN);
+            VJMPERR2( 0 );
+        }
+        strncpy(thee->file, filename, VMAX_ARGLEN);
         if (thee->rwkey==VIO_R) {
             thee->fp = fopen(thee->file, "r");
         } else { /* (thee->rwkey==VIO_W) */
@@ -638,7 +643,12 @@ VPUBLIC int Vio_ctor2(Vio *thee, const char *socktype, const char *datafrmt,
     } else if (thee->type==VIO_INET) {
 
         /* filename is the port number for the socket */
-        strncpy(thee->file, filename, 80);
+        if (strlen(filename) >= VMAX_ARGLEN) {
+            fprintf(stderr, "Vio_ctor2: Filename <%d> exceeds max <%d>!\n",
+                (int)strlen(filename), VMAX_ARGLEN);
+            VJMPERR2( 0 );
+        }
+        strncpy(thee->file, filename, VMAX_ARGLEN);
 
         /* create the socket address structure */
         thee->name = (struct sockaddr_in *)
@@ -1461,7 +1471,7 @@ VPUBLIC int Vio_scanf(Vio *thee, char *parms, ... )
 
   VERROR1:
     va_end(ap);
-    //fprintf(stderr,"Vio_scanf: Format problem with input.\n");
+    /* fprintf(stderr,"Vio_scanf: Format problem with input.\n"); */
   VERROR2:
     thee->error = 1;
     return 0;
@@ -1608,7 +1618,7 @@ VPUBLIC int Vio_read(Vio *thee, char *buf, int bufsize)
         if ( (thee->type==VIO_SDIO)
           || (thee->type==VIO_FILE) ) {
             rc = fread(buf, sizeof(char), (unsigned int)bufsize, thee->fp);
-            /* MIKE: if (rc!=bufsize), make SURE EOF was reached! */
+            /* CMIKE: if (rc!=bufsize), make SURE EOF was reached! */
         } else if (thee->type==VIO_BUFF) {
             ilen = VMIN2( bufsize, thee->VIObufferLen - thee->VIObufferPtr );
             for (i=0; i<ilen; i++)
@@ -1618,7 +1628,7 @@ VPUBLIC int Vio_read(Vio *thee, char *buf, int bufsize)
         } else if ( (thee->type==VIO_UNIX)
                  || (thee->type==VIO_INET) ) {
             rc = readn(thee->soc, buf, (unsigned int)bufsize);
-            /* MIKE: if (rc!=bufsize), make SURE EOF was reached! */
+            /* CMIKE: if (rc!=bufsize), make SURE EOF was reached! */
         } else {
             fprintf(stderr,"Vio_read: Bad type found <%d>\n", thee->type);
             rc = 0;
@@ -2208,7 +2218,7 @@ VPRIVATE char* asc_getToken(ASC *thee, char *tok, int toksize)
     return tok;
 
   VERROR1:
-    //fprintf(stderr,"asc_getToken: Error occurred (bailing out).\n");
+    /* fprintf(stderr,"asc_getToken: Error occurred (bailing out).\n"); */
     return VNULL;
 }
 
