@@ -6,7 +6,7 @@
  *  @file     vfetk.h
  *  @ingroup  Vfetk
  *  @brief    Contains declarations for class Vfetk
- *  @version  $Id: vfetk.h 1092 2007-04-27 15:05:41Z sdg0919 $
+ *  @version  $Id: vfetk.h 1251 2008-03-30 22:32:00Z sobolevnrm $
  *  @author   Nathan A. Baker
  *
  *  @attention
@@ -21,50 +21,38 @@
  *
  * Additional contributing authors listed in the code documentation.
  *
- * Copyright (c) 2002-2007.  Washington University in St. Louis.
- * All Rights Reserved.
- * Portions Copyright (c) 1999-2002.  The Regents of the University of
- * California.  
- * Portions Copyright (c) 1995.  Michael Holst.
+ * Copyright (c) 2002-2008, Washington University in St. Louis.
+ * Portions Copyright (c) 2002-2008.  Nathan A. Baker
+ * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
+ * Portions Copyright (c) 1995.  Michael Holst
  *
- * This file is part of APBS.
- *
- * APBS is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * APBS is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with APBS; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
- *
- * Linking APBS statically or dynamically with other modules is making a
- * combined work based on APBS. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
+ * All rights reserved.
  * 
- * SPECIAL GPL EXCEPTION
- * In addition, as a special exception, the copyright holders of APBS
- * give you permission to combine the APBS program with free software
- * programs and libraries that are released under the GNU LGPL or with
- * code included in releases of ISIM, Ion Simulator Interface, PMV, PyMOL
- * SMOL, VMD, and Vision. Such combined software may be linked with APBS and 
- * redistributed together in original or modified form as mere aggregation
- * without requirement that the entire work be under the scope of the GNU 
- * General Public License. This special exception permission is also extended
- * to any software listed in the SPECIAL GPL EXCEPTION clauses by the PMG,
- * FEtk, MC, or MALOC libraries.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met: 
+ *
+ * -  Redistributions of source code must retain the above copyright notice, this
+ * list of conditions and the following disclaimer.  
  * 
- * Note that people who make modified versions of APBS are not obligated
- * to grant this special exception for their modified versions; it is
- * their choice whether to do so. The GNU General Public License gives
- * permission to release a modified version without this exception; this
- * exception also makes it possible to release a modified version which
- * carries forward this exception.
+ * - Redistributions in binary form must reproduce the above copyright notice,
+ * this list of conditions and the following disclaimer in the documentation
+ * and/or other materials provided with the distribution.
+ * 
+ * - Neither the name of Washington University in St. Louis nor the names of its
+ * contributors may be used to endorse or promote products derived from this
+ * software without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
+ * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
+ * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+ * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+ * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * @endverbatim
  */
@@ -103,6 +91,23 @@ enum eVfetk_LsolvType {
  */
 typedef enum eVfetk_LsolvType Vfetk_LsolvType;
 
+
+/**
+ * @brief	Mesh loading operation
+ * @ingroup	Vfetk
+ */
+enum eVfetk_MeshLoad {
+    VML_DIRICUBE,  /**< Dirichlet cube */
+    VML_NEUMCUBE,  /**< Neumann cube */
+    VML_EXTERNAL  /**< External mesh (from socket) */
+};
+
+/**
+ * @brief  Declare FEMparm_GuessType type
+ * @ingroup  Vfetk
+ */
+typedef enum eVfetk_MeshLoad Vfetk_MeshLoad;
+
 /**
  * @brief  Non-linear solver type 
  * @ingroup Vfetk
@@ -514,17 +519,30 @@ VEXTERNC void Bmat_printHB(
         char *fname /** Filename for output */
         );
 
-/** 
- * @brief   Generates a simple cubic tetrahedral mesh
+/**
+ * @brief	Construct a rectangular mesh (in the current Vfetk object)
  * @ingroup Vfetk
- * @author  Nathan Baker (based on Mike Holst's Gem_makeCube code)
- * @return  1 if successful, 0 otherwise
+ * @author	Nathan Baker
  */
-VEXTERNC int Vfetk_genCube(
-        Vfetk *thee, /** The Vfetk object */
-        double center[VAPBS_DIM], /** Desired mesh center (in &Aring;) */
-        double length[VAPBS_DIM] /** Desired mesh length (in &Aring;) */
-        );
+VEXTERNC Vrc_Codes Vfetk_genCube(
+								 Vfetk *thee,  /** Vfetk object */
+								 double center[3],  /** Center for mesh */
+								 double length[3],  /** Mesh lengths */
+								 Vfetk_MeshLoad meshType  /** Mesh boundary conditions */
+								 );
+ 
+/**
+ * @brief	Loads a mesh into the Vfetk (and associated) object(s).
+ * @ingroup	Vfetk
+ * @author	Nathan Baker
+ */
+VEXTERNC Vrc_Codes Vfetk_loadMesh(
+								  Vfetk *thee, /** Vfetk object to load into */
+								  double center[3],  /** Center for mesh (if constructed) */
+								  double length[3],  /** Mesh lengths (if constructed) */
+								  Vfetk_MeshLoad meshType,  /** Type of mesh to load */
+								  Vio *sock  /** Socket for external mesh data (NULL otherwise) */
+								  );
 
 /**
  * @brief  Constructs the FEtk PDE object 
@@ -976,5 +994,15 @@ VEXTERNC int Vfetk_write(
         Vdata_Format format /** Data format */
         );
 
+/**
+ * @brief  Load a Gem geometry manager object into Vfetk
+ * @ingroup Vfetk
+ * @author  Nathan Baker
+ */
+VEXTERNC Vrc_Codes Vfetk_loadGem(
+								 Vfetk *thee, /**< Destination */
+								 Gem *gm /**< Geometry manager source */
+								 );
+
 
 #endif /* ifndef _VFETK_H_ */
