@@ -3,7 +3,7 @@
  *  @ingroup Vfetk
  *  @author  Nathan Baker
  *  @brief   Class Vfetk methods
- *  @version $Id: vfetk.c 1095 2007-06-04 15:44:22Z sdg0919 $
+ *  @version $Id: vfetk.c 1251 2008-03-30 22:32:00Z sobolevnrm $
  *  @attention
  *  @verbatim
  *
@@ -16,50 +16,38 @@
  *
  * Additional contributing authors listed in the code documentation.
  *
- * Copyright (c) 2002-2007.  Washington University in St. Louis.
- * All Rights Reserved.
- * Portions Copyright (c) 1999-2002.  The Regents of the University of
- * California.  
- * Portions Copyright (c) 1995.  Michael Holst.
+ * Copyright (c) 2002-2008, Washington University in St. Louis.
+ * Portions Copyright (c) 2002-2008.  Nathan A. Baker
+ * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
+ * Portions Copyright (c) 1995.  Michael Holst
  *
- * This file is part of APBS.
- *
- * APBS is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * APBS is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with APBS; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
- *
- * Linking APBS statically or dynamically with other modules is making a
- * combined work based on APBS. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
+ * All rights reserved.
  * 
- * SPECIAL GPL EXCEPTION
- * In addition, as a special exception, the copyright holders of APBS
- * give you permission to combine the APBS program with free software
- * programs and libraries that are released under the GNU LGPL or with
- * code included in releases of ISIM, Ion Simulator Interface, PMV, PyMOL
- * SMOL, VMD, and Vision. Such combined software may be linked with APBS and 
- * redistributed together in original or modified form as mere aggregation
- * without requirement that the entire work be under the scope of the GNU 
- * General Public License. This special exception permission is also extended
- * to any software listed in the SPECIAL GPL EXCEPTION clauses by the PMG,
- * FEtk, MC, or MALOC libraries.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met: 
+ *
+ * -  Redistributions of source code must retain the above copyright notice, this
+ * list of conditions and the following disclaimer.  
  * 
- * Note that people who make modified versions of APBS are not obligated
- * to grant this special exception for their modified versions; it is
- * their choice whether to do so. The GNU General Public License gives
- * permission to release a modified version without this exception; this
- * exception also makes it possible to release a modified version which
- * carries forward this exception.
+ * - Redistributions in binary form must reproduce the above copyright notice,
+ * this list of conditions and the following disclaimer in the documentation
+ * and/or other materials provided with the distribution.
+ * 
+ * - Neither the name of Washington University in St. Louis nor the names of its
+ * contributors may be used to endorse or promote products derived from this
+ * software without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
+ * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
+ * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+ * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+ * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * @endverbatim
  */
@@ -552,7 +540,7 @@ VPUBLIC Vfetk* Vfetk_ctor(Vpbe *pbe, Vhal_PBEType type) {
 
     return thee;
 }
-
+	 
 VPUBLIC int Vfetk_ctor2(Vfetk *thee, Vpbe *pbe, Vhal_PBEType type) {
 
     int i;
@@ -571,7 +559,7 @@ VPUBLIC int Vfetk_ctor2(Vfetk *thee, Vpbe *pbe, Vhal_PBEType type) {
     thee->vmem = Vmem_ctor("APBS::VFETK");
 
     /* Set up FEtk objects */
-    Vnm_print(0, "Vfetk_ctor2:  Constructing PDE...\n");
+	Vnm_print(0, "Vfetk_ctor2:  Constructing PDE...\n");
     thee->pde = Vfetk_PDE_ctor(thee);
     Vnm_print(0, "Vfetk_ctor2:  Constructing Gem...\n");
     thee->gm = Gem_ctor(thee->vmem, thee->pde);
@@ -579,7 +567,7 @@ VPUBLIC int Vfetk_ctor2(Vfetk *thee, Vpbe *pbe, Vhal_PBEType type) {
     thee->aprx = Aprx_ctor(thee->vmem, thee->gm, thee->pde);
     Vnm_print(0, "Vfetk_ctor2:  Constructing Aprx...\n");
     thee->am = AM_ctor(thee->vmem, thee->aprx);
-
+	
     /* Reset refinement level */
     thee->level = 0;
 
@@ -598,7 +586,7 @@ VPUBLIC int Vfetk_ctor2(Vfetk *thee, Vpbe *pbe, Vhal_PBEType type) {
     var.fetk = thee;
     var.initGreen = 0;
 
-    /* Set up the external Gem subdivision hook */
+	/* Set up the external Gem subdivision hook */
     Gem_setExternalUpdateFunction(thee->gm, Vfetk_externalUpdateFunction);
 
     /* Set up ion-related variables */
@@ -640,7 +628,6 @@ VPUBLIC void Vfetk_dtor2(Vfetk *thee) {
     Vcsm_dtor(&(thee->csm));
     AM_dtor(&(thee->am));
     Aprx_dtor(&(thee->aprx));
-    Gem_dtor(&(thee->gm));
     Vfetk_PDE_dtor(&(thee->pde));
     Vmem_dtor(&(thee->vmem));
 }
@@ -846,12 +833,14 @@ VPUBLIC unsigned long int Vfetk_memChk(Vfetk *thee) {
     return memUse;
 }
 
-
-VPUBLIC int Vfetk_genCube(Vfetk *thee, double center[3], double length[3]) {
-
+VPUBLIC Vrc_Codes Vfetk_genCube(
+								Vfetk *thee,  
+								double center[3],
+								double length[3],
+								Vfetk_MeshLoad meshType) {
     AM *am = VNULL;
     Gem *gm = VNULL;
-
+	
     int skey = 0;  /* Simplex format */
     char *key = "r";  /* Read */
     char *iodev = "BUFF";  /* Buffer */
@@ -864,33 +853,43 @@ VPUBLIC int Vfetk_genCube(Vfetk *thee, double center[3], double length[3]) {
     VV *vx = VNULL;
     int i, j;
     double x;
-
+	
     VASSERT(thee != VNULL);
     am = thee->am;
     VASSERT(am != VNULL);
     gm = thee->gm;
     VASSERT(gm != VNULL);
-
+	
     /* @note This code is based on Gem_makeCube by Mike Holst */
     /* Write mesh string to buffer and read back */
-#ifdef DONEUMANN
-    bufsize = strlen(neumCubeString);
-    Vnm_print(2, "DEBUG -- USING NEUMANN MESH!\n");
-    VASSERT( bufsize <= VMAX_BUFSIZE );
-    strncpy(buf, neumCubeString, VMAX_BUFSIZE);
-#else
-    bufsize = strlen(diriCubeString);
-    VASSERT( bufsize <= VMAX_BUFSIZE );
-    strncpy(buf, diriCubeString, VMAX_BUFSIZE); 
-#endif
+	switch (meshType) {
+		case VML_DIRICUBE:
+			bufsize = strlen(diriCubeString);
+			VASSERT( bufsize <= VMAX_BUFSIZE );
+			strncpy(buf, diriCubeString, VMAX_BUFSIZE); 
+			break;
+		case VML_NEUMCUBE:
+			bufsize = strlen(neumCubeString);
+			Vnm_print(2, "Vfetk_genCube:  WARNING!  USING EXPERIMENTAL NEUMANN BOUNDARY CONDITIONS!\n");
+			VASSERT( bufsize <= VMAX_BUFSIZE );
+			strncpy(buf, neumCubeString, VMAX_BUFSIZE);
+			break;
+		case VML_EXTERNAL:
+			Vnm_print(2, "Vfetk_genCube:  Got request for external mesh!\n");
+			Vnm_print(2, "Vfetk_genCube:  How did we get here?\n");
+			return VRC_FAILURE;
+			break;
+		default:
+			Vnm_print(2, "Vfetk_genCube:  Unknown mesh type (%d)\n", meshType);
+			return VRC_FAILURE;
+	}
     VASSERT( VNULL != (sock=Vio_socketOpen(key,iodev,iofmt,iohost,iofile)) );
     Vio_bufTake(sock, buf, bufsize);
     AM_read(am, skey, sock);
-#if 0
-    Vio_socketClose(&sock);
+	Vio_connectFree(sock);
+    Vio_bufGive(sock);
     Vio_dtor(&sock);
-#endif
-
+	
     /* Scale (unit) cube */
     for (i=0; i<Gem_numVV(gm); i++) {
         vx = Gem_VV(gm, i);
@@ -900,7 +899,7 @@ VPUBLIC int Vfetk_genCube(Vfetk *thee, double center[3], double length[3]) {
             VV_setCoord(vx, j, x);
         }
     }
-
+	
     /* Add new center */
     for (i=0; i<Gem_numVV(gm); i++) {
         vx = Gem_VV(gm, i);
@@ -910,35 +909,57 @@ VPUBLIC int Vfetk_genCube(Vfetk *thee, double center[3], double length[3]) {
             VV_setCoord(vx, j, x);
         }
     }
+	
+	
+    return VRC_SUCCESS;
+}
 
-    /* Setup charge-simplex map */
+VPUBLIC Vrc_Codes Vfetk_loadMesh(
+								 Vfetk *thee,
+								 double center[3],
+								 double length[3],
+								 Vfetk_MeshLoad meshType,
+								 Vio *sock) {
+	
+	Vrc_Codes vrc;
+	int skey = 0;  /* Simplex format */
+
+	
+	switch (meshType) {
+		case VML_EXTERNAL:
+			if (sock == VNULL) {
+				Vnm_print(2, "Vfetk_loadMesh:  Got NULL socket!\n");
+				return VRC_FAILURE;
+			}
+			AM_read(thee->am, skey, sock);
+			Vio_connectFree(sock);
+			Vio_bufGive(sock);
+			Vio_dtor(&sock);
+			break;
+		case VML_DIRICUBE:
+			vrc = Vfetk_genCube(thee, center, length, meshType);
+			if (vrc == VRC_FAILURE) return VRC_FAILURE;
+			break;
+		case VML_NEUMCUBE:
+			vrc = Vfetk_genCube(thee, center, length, meshType);
+			if (vrc == VRC_FAILURE) return VRC_FAILURE;
+			break;
+		default:
+			Vnm_print(2, "Vfetk_loadMesh:  unrecognized mesh type (%d)!\n", 
+					  meshType);
+			return VRC_FAILURE;
+	};
+		
+	/* Setup charge-simplex map */
     Vnm_print(0, "Vfetk_ctor2:  Constructing Vcsm...\n");
     thee->csm = VNULL;
     thee->csm = Vcsm_ctor(Vpbe_getValist(thee->pbe), thee->gm);
     VASSERT(thee->csm != VNULL);
     Vcsm_init(thee->csm);
-
-    /* Destroy socket */
-    Vio_connectFree(sock);
-    Vio_bufGive(sock);
-    Vio_dtor(&sock);
-
-    return 1;
+	
+	return VRC_SUCCESS;
 }
 
-VPUBLIC void Vfetk_readMesh(Vfetk *thee, int skey, Vio *sock) {
-
-    VASSERT(thee != VNULL);
-    AM_read(thee->am, skey, sock);
-
-    /* Setup charge-simplex map */
-    Vnm_print(0, "Vfetk_ctor2:  Constructing Vcsm...\n");
-    thee->csm = VNULL;
-    thee->csm = Vcsm_ctor(Vpbe_getValist(thee->pbe), thee->gm);
-    VASSERT(thee->csm != VNULL);
-    Vcsm_init(thee->csm);
-
-}
 
 VPUBLIC void Bmat_printHB( Bmat *thee, char *fname ) {
 
@@ -1839,7 +1860,8 @@ VPUBLIC int Vfetk_PDE_markSimplex(int dim, int dimII, int simplexType,
     type = var.fetk->type;
 
     /* Check to see if this simplex is smaller than the target size */
-    Gem_longestEdge(var.fetk->gm, simp, &edgeLength);
+    /* NAB WARNING:  I am providing face=-1 here to conform to the new MC API; however, I'm not sure if this is the correct behavior. */
+    Gem_longestEdge(var.fetk->gm, simp, -1, &edgeLength);
     if (edgeLength < targetRes) return 0;
 
     /* For non-regularized PBE, check charge-simplex map */
