@@ -3,7 +3,7 @@
  *  @ingroup APOLparm
  *  @author  David Gohara
  *  @brief   Class APOLparm methods
- *  @version $Id: apolparm.c 907 2006-07-27 20:36:20Z sdg0919 $
+ *  @version $Id: apolparm.c 1251 2008-03-30 22:32:00Z sobolevnrm $
  *  @attention
  *  @verbatim
  *
@@ -16,50 +16,38 @@
  *
  * Additional contributing authors listed in the code documentation.
  *
- * Copyright (c) 2002-2007.  Washington University in St. Louis.
- * All Rights Reserved.
- * Portions Copyright (c) 1999-2002.  The Regents of the University of
- * California.  
- * Portions Copyright (c) 1995.  Michael Holst.
+ * Copyright (c) 2002-2008, Washington University in St. Louis.
+ * Portions Copyright (c) 2002-2008.  Nathan A. Baker
+ * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
+ * Portions Copyright (c) 1995.  Michael Holst
  *
- * This file is part of APBS.
- *
- * APBS is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * APBS is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with APBS; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
- *
- * Linking APBS statically or dynamically with other modules is making a
- * combined work based on APBS. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
+ * All rights reserved.
  * 
- * SPECIAL GPL EXCEPTION
- * In addition, as a special exception, the copyright holders of APBS
- * give you permission to combine the APBS program with free software
- * programs and libraries that are released under the GNU LGPL or with
- * code included in releases of ISIM, Ion Simulator Interface, PMV, PyMOL
- * SMOL, VMD, and Vision. Such combined software may be linked with APBS and 
- * redistributed together in original or modified form as mere aggregation
- * without requirement that the entire work be under the scope of the GNU 
- * General Public License. This special exception permission is also extended
- * to any software listed in the SPECIAL GPL EXCEPTION clauses by the PMG,
- * APOLtk, MC, or MALOC libraries.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met: 
+ *
+ * -  Redistributions of source code must retain the above copyright notice, this
+ * list of conditions and the following disclaimer.  
  * 
- * Note that people who make modified versions of APBS are not obligated
- * to grant this special exception for their modified versions; it is
- * their choice whether to do so. The GNU General Public License gives
- * permission to release a modified version without this exception; this
- * exception also makes it possible to release a modified version which
- * carries forward this exception.
+ * - Redistributions in binary form must reproduce the above copyright notice,
+ * this list of conditions and the following disclaimer in the documentation
+ * and/or other materials provided with the distribution.
+ * 
+ * - Neither the name of Washington University in St. Louis nor the names of its
+ * contributors may be used to endorse or promote products derived from this
+ * software without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
+ * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
+ * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+ * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+ * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * @endverbatim
  */
@@ -68,7 +56,7 @@
 #include "apbscfg.h"
 #include "apbs/apolparm.h"
 
-VEMBED(rcsid="$Id: apolparm.c 907 2006-07-27 20:36:20Z sdg0919 $")
+VEMBED(rcsid="$Id: apolparm.c 1251 2008-03-30 22:32:00Z sobolevnrm $")
 
 #if !defined(VINLINE_MGPARM)
 
@@ -80,16 +68,17 @@ VPUBLIC APOLparm* APOLparm_ctor() {
     APOLparm *thee = VNULL;
     thee = Vmem_malloc(VNULL, 1, sizeof(APOLparm));
     VASSERT( thee != VNULL);
-    VASSERT( APOLparm_ctor2(thee) );
+    VASSERT( APOLparm_ctor2(thee) == VRC_SUCCESS );
 
     return thee;
 }
 
-VPUBLIC int APOLparm_ctor2(APOLparm *thee) {
+VPUBLIC Vrc_Codes APOLparm_ctor2(APOLparm *thee) {
 
-    if (thee == VNULL) return 0;
+    int i;
+
+    if (thee == VNULL) return VRC_FAILURE;
 
-	int i;
     thee->parsed = 0;
 	
     thee->setgrid = 0;
@@ -105,13 +94,15 @@ VPUBLIC int APOLparm_ctor2(APOLparm *thee) {
 	thee->settemp = 0;
     thee->setgamma = 0;
 	
+	thee->setwat = 0;
+	
 	thee->sav = 0.0;
 	thee->sasa = 0.0;
 	thee->wcaEnergy = 0.0;
 	
 	for(i=0;i<3;i++) thee->totForce[i] = 0.0;
 	
-    return 1; 
+    return VRC_SUCCESS; 
 }
 
 VPUBLIC void APOLparm_copy(
@@ -162,6 +153,8 @@ VPUBLIC void APOLparm_copy(
 	thee->calcforce = source->calcforce ;
 	thee->setcalcforce = source->setcalcforce ;
 	
+	thee->setwat = source->setwat ;
+	
 	thee->sav = source->sav;
 	thee->sasa = source->sasa;
 	thee->wcaEnergy = source->wcaEnergy;
@@ -183,20 +176,65 @@ VPUBLIC void APOLparm_dtor(APOLparm **thee) {
 
 VPUBLIC void APOLparm_dtor2(APOLparm *thee) { ; }
 
-VPUBLIC int APOLparm_check(APOLparm *thee) { 
-
-    int rc;
-    rc = 1;
+VPUBLIC Vrc_Codes APOLparm_check(APOLparm *thee) { 
 
+    
+    Vrc_Codes rc;
+    rc = VRC_SUCCESS;
+	
     if (!thee->parsed) {
         Vnm_print(2, "APOLparm_check:  not filled!\n");
-        return 0;
+        return VRC_FAILURE;
+    }
+    if (!thee->setgrid) {
+        Vnm_print(2, "APOLparm_check:  grid not set!\n");
+        rc = VRC_FAILURE;
+    }
+    if (!thee->setmolid) {
+        Vnm_print(2, "APOLparm_check:  molid not set!\n");
+        rc = VRC_FAILURE;
+    }
+    if (!thee->setbconc) {
+        Vnm_print(2, "APOLparm_check:  bconc not set!\n");
+        rc = VRC_FAILURE;
+    }
+    if (!thee->setsdens) {
+        Vnm_print(2, "APOLparm_check:  sdens not set!\n");
+        rc = VRC_FAILURE;
+    }
+    if (!thee->setdpos) {
+        Vnm_print(2, "APOLparm_check:  dpos not set!\n");
+        rc = VRC_FAILURE;
+    }
+    if (!thee->setpress) {
+        Vnm_print(2, "APOLparm_check:  press not set!\n");
+        rc = VRC_FAILURE;
+    }
+    if (!thee->setsrfm) {
+        Vnm_print(2, "APOLparm_check:  srfm not set!\n");
+        rc = VRC_FAILURE;
+    }
+    if (!thee->setsrad) {
+        Vnm_print(2, "APOLparm_check:  srad not set!\n");
+        rc = VRC_FAILURE;
+    }
+    if (!thee->setswin) {
+        Vnm_print(2, "APOLparm_check:  swin not set!\n");
+        rc = VRC_FAILURE;
+    }
+    if (!thee->settemp) {
+        Vnm_print(2, "APOLparm_check:  temp not set!\n");
+        rc = VRC_FAILURE;
+    }
+	if (!thee->setgamma) {
+        Vnm_print(2, "APOLparm_check:  gamma not set!\n");
+        rc = VRC_FAILURE;
     }
-    
     return rc;
+	
 }
 
-VPRIVATE int APOLparm_parseGRID(APOLparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes APOLparm_parseGRID(APOLparm *thee, Vio *sock) {
 	
 	char tok[VMAX_BUFSIZE];
 	double tf;
@@ -205,29 +243,29 @@ VPRIVATE int APOLparm_parseGRID(APOLparm *thee, Vio *sock) {
 	if (sscanf(tok, "%lf", &tf) == 0) {
 		Vnm_print(2, "NOsh:  Read non-float (%s) while parsing GRID \
 keyword!\n", tok);
-		return -1;
+		return VRC_WARNING;
 	} else thee->grid[0] = tf;
 	VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
 	if (sscanf(tok, "%lf", &tf) == 0) {
 		Vnm_print(2, "NOsh:  Read non-float (%s) while parsing GRID \
 keyword!\n", tok);
-		return -1;
+		return VRC_WARNING;
 	} else thee->grid[1] = tf;
 	VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
 	if (sscanf(tok, "%lf", &tf) == 0) {
 		Vnm_print(2, "NOsh:  Read non-float (%s) while parsing GRID \
 keyword!\n", tok);
-		return -1;
+		return VRC_WARNING;
 	} else thee->grid[2] = tf;
     thee->setgrid = 1;
-    return 1;
+    return VRC_SUCCESS;
 	
 VERROR1:
         Vnm_print(2, "parseAPOL:  ran out of tokens!\n");
-	return -1;
+	return VRC_WARNING;
 }
 
-VPRIVATE int APOLparm_parseMOL(APOLparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes APOLparm_parseMOL(APOLparm *thee, Vio *sock) {
     int ti;
     char tok[VMAX_BUFSIZE];
 	
@@ -235,18 +273,18 @@ VPRIVATE int APOLparm_parseMOL(APOLparm *thee, Vio *sock) {
     if (sscanf(tok, "%d", &ti) == 0) {
         Vnm_print(2, "NOsh:  Read non-int (%s) while parsing MOL \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     } 
     thee->molid = ti;
     thee->setmolid = 1;
-    return 1;
+    return VRC_SUCCESS;
 	
 VERROR1:
         Vnm_print(2, "parseAPOL:  ran out of tokens!\n");
-	return -1;
+	return VRC_WARNING;
 }
 
-VPRIVATE int APOLparm_parseSRFM(APOLparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes APOLparm_parseSRFM(APOLparm *thee, Vio *sock) {
     char tok[VMAX_BUFSIZE];
 	
     VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
@@ -254,21 +292,21 @@ VPRIVATE int APOLparm_parseSRFM(APOLparm *thee, Vio *sock) {
     if (Vstring_strcasecmp(tok, "sacc") == 0) {
         thee->srfm = VSM_MOL;
         thee->setsrfm = 1;
-        return 1;
+        return VRC_SUCCESS;
     } else {
         printf("parseAPOL: Unrecongnized keyword (%s) when parsing srfm!\n", tok);
 		printf("parseAPOL: Accepted values for srfm = sacc\n");
-        return -1;
+        return VRC_WARNING;
     }
 	
-    return 0;
+    return VRC_FAILURE;
 	
 VERROR1:
         Vnm_print(2, "parseAPOL:  ran out of tokens!\n");
-	return -1;
+	return VRC_WARNING;
 }
 
-VPRIVATE int APOLparm_parseSRAD(APOLparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes APOLparm_parseSRAD(APOLparm *thee, Vio *sock) {
     char tok[VMAX_BUFSIZE];
     double tf;
 	
@@ -276,18 +314,18 @@ VPRIVATE int APOLparm_parseSRAD(APOLparm *thee, Vio *sock) {
     if (sscanf(tok, "%lf", &tf) == 0) {
         Vnm_print(2, "NOsh:  Read non-float (%s) while parsing SRAD \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     }
     thee->srad = tf;
     thee->setsrad = 1;
-    return 1;
+    return VRC_SUCCESS;
 	
 VERROR1:
         Vnm_print(2, "parseAPOL:  ran out of tokens!\n");
-	return -1;
+	return VRC_WARNING;
 }
 
-VPRIVATE int APOLparm_parseSWIN(APOLparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes APOLparm_parseSWIN(APOLparm *thee, Vio *sock) {
     char tok[VMAX_BUFSIZE];
     double tf;
 	
@@ -295,18 +333,18 @@ VPRIVATE int APOLparm_parseSWIN(APOLparm *thee, Vio *sock) {
     if (sscanf(tok, "%lf", &tf) == 0) {
         Vnm_print(2, "NOsh:  Read non-float (%s) while parsing SWIN \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     }
     thee->swin = tf;
     thee->setswin = 1;
-    return 1;
+    return VRC_SUCCESS;
 	
 VERROR1:
         Vnm_print(2, "parseAPOL:  ran out of tokens!\n");
-	return -1;
+	return VRC_WARNING;
 }
 
-VPRIVATE int APOLparm_parseTEMP(APOLparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes APOLparm_parseTEMP(APOLparm *thee, Vio *sock) {
     char tok[VMAX_BUFSIZE];
     double tf;
 	
@@ -314,18 +352,18 @@ VPRIVATE int APOLparm_parseTEMP(APOLparm *thee, Vio *sock) {
     if (sscanf(tok, "%lf", &tf) == 0) {
         Vnm_print(2, "NOsh:  Read non-float (%s) while parsing TEMP \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     }
     thee->temp = tf;
     thee->settemp = 1;
-    return 1;
+    return VRC_SUCCESS;
 	
 VERROR1:
         Vnm_print(2, "parseAPOL:  ran out of tokens!\n");
-	return -1;
+	return VRC_WARNING;
 }
 
-VPRIVATE int APOLparm_parseGAMMA(APOLparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes APOLparm_parseGAMMA(APOLparm *thee, Vio *sock) {
     char tok[VMAX_BUFSIZE];
     double tf;
 	
@@ -333,18 +371,18 @@ VPRIVATE int APOLparm_parseGAMMA(APOLparm *thee, Vio *sock) {
     if (sscanf(tok, "%lf", &tf) == 0) {
         Vnm_print(2, "NOsh:  Read non-float (%s) while parsing GAMMA \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     }
     thee->gamma = tf;
     thee->setgamma = 1;
-    return 1;
+    return VRC_SUCCESS;
 	
 VERROR1:
         Vnm_print(2, "parseAPOL:  ran out of tokens!\n");
-	return -1;
+	return VRC_WARNING;
 }
 
-VPRIVATE int APOLparm_parseCALCENERGY(APOLparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes APOLparm_parseCALCENERGY(APOLparm *thee, Vio *sock) {
     char tok[VMAX_BUFSIZE];
     int ti;
 	
@@ -372,32 +410,32 @@ VPRIVATE int APOLparm_parseCALCENERGY(APOLparm *thee, Vio *sock) {
                 break;
         }
         Vnm_print(2, "\" instead.\n");
-        return 1;
+        return VRC_SUCCESS;
     } else if (Vstring_strcasecmp(tok, "no") == 0) {
         thee->calcenergy = ACE_NO;
         thee->setcalcenergy = 1;
-        return 1;
+        return VRC_SUCCESS;
     } else if (Vstring_strcasecmp(tok, "total") == 0) {
         thee->calcenergy = ACE_TOTAL;
         thee->setcalcenergy = 1;
-        return 1;
+        return VRC_SUCCESS;
     } else if (Vstring_strcasecmp(tok, "comps") == 0) {
         thee->calcenergy = ACE_COMPS;
         thee->setcalcenergy = 1;
-        return 1;
+        return VRC_SUCCESS;
     } else {
         Vnm_print(2, "NOsh:  Unrecognized parameter (%s) while parsing \
 calcenergy!\n", tok);
-        return -1;
+        return VRC_WARNING;
     }
-    return 0;
+    return VRC_FAILURE;
 	
 VERROR1:
         Vnm_print(2, "parseAPOL:  ran out of tokens!\n");
-	return -1;
+	return VRC_WARNING;
 }
 
-VPRIVATE int APOLparm_parseCALCFORCE(APOLparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes APOLparm_parseCALCFORCE(APOLparm *thee, Vio *sock) {
     char tok[VMAX_BUFSIZE];
     int ti;
 	
@@ -425,32 +463,32 @@ VPRIVATE int APOLparm_parseCALCFORCE(APOLparm *thee, Vio *sock) {
                 break;
         }
         Vnm_print(2, "\" instead.\n");
-        return 1;
+        return VRC_SUCCESS;
     } else if (Vstring_strcasecmp(tok, "no") == 0) {
         thee->calcforce = ACF_NO;
         thee->setcalcforce = 1;
-        return 1;
+        return VRC_SUCCESS;
     } else if (Vstring_strcasecmp(tok, "total") == 0) {
         thee->calcforce = ACF_TOTAL;
         thee->setcalcforce = 1;
-        return 1;
+        return VRC_SUCCESS;
     } else if (Vstring_strcasecmp(tok, "comps") == 0) {
         thee->calcforce = ACF_COMPS;
         thee->setcalcforce = 1;
-        return 1;
+        return VRC_SUCCESS;
     } else {
         Vnm_print(2, "NOsh:  Unrecognized parameter (%s) while parsing \
 calcforce!\n", tok);
-        return -1;
+        return VRC_WARNING;
     }
-    return 0;
+    return VRC_FAILURE;
 	
 VERROR1:
         Vnm_print(2, "parseAPOL:  ran out of tokens!\n");
-	return -1;
+	return VRC_WARNING;
 }
 
-VPRIVATE int APOLparm_parseBCONC(APOLparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes APOLparm_parseBCONC(APOLparm *thee, Vio *sock) {
     char tok[VMAX_BUFSIZE];
     double tf;
 	
@@ -458,18 +496,18 @@ VPRIVATE int APOLparm_parseBCONC(APOLparm *thee, Vio *sock) {
     if (sscanf(tok, "%lf", &tf) == 0) {
         Vnm_print(2, "NOsh:  Read non-float (%s) while parsing BCONC \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     }
     thee->bconc = tf;
     thee->setbconc = 1;
-    return 1;
+    return VRC_SUCCESS;
 	
 VERROR1:
         Vnm_print(2, "parseAPOL:  ran out of tokens!\n");
-	return -1;
+	return VRC_WARNING;
 }
 
-VPRIVATE int APOLparm_parseSDENS(APOLparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes APOLparm_parseSDENS(APOLparm *thee, Vio *sock) {
     char tok[VMAX_BUFSIZE];
     double tf;
 	
@@ -477,18 +515,18 @@ VPRIVATE int APOLparm_parseSDENS(APOLparm *thee, Vio *sock) {
     if (sscanf(tok, "%lf", &tf) == 0) {
         Vnm_print(2, "NOsh:  Read non-float (%s) while parsing SDENS \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     }
     thee->sdens = tf;
     thee->setsdens = 1;
-    return 1;
+    return VRC_SUCCESS;
 	
 VERROR1:
         Vnm_print(2, "parseAPOL:  ran out of tokens!\n");
-	return -1;
+	return VRC_WARNING;
 }
 
-VPRIVATE int APOLparm_parseDPOS(APOLparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes APOLparm_parseDPOS(APOLparm *thee, Vio *sock) {
     char tok[VMAX_BUFSIZE];
     double tf;
 	
@@ -496,7 +534,7 @@ VPRIVATE int APOLparm_parseDPOS(APOLparm *thee, Vio *sock) {
     if (sscanf(tok, "%lf", &tf) == 0) {
         Vnm_print(2, "NOsh:  Read non-float (%s) while parsing SDENS \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     }
     thee->dpos = tf;
     thee->setdpos = 1;
@@ -510,14 +548,14 @@ safely ignore this message.\n");
 or equal to 0.001.\n\n");
 	}
 	
-    return 1;
+    return VRC_SUCCESS;
 	
 VERROR1:
         Vnm_print(2, "parseAPOL:  ran out of tokens!\n");
-	return -1;
+	return VRC_WARNING;
 }
 
-VPRIVATE int APOLparm_parsePRESS(APOLparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes APOLparm_parsePRESS(APOLparm *thee, Vio *sock) {
     char tok[VMAX_BUFSIZE];
     double tf;
 	
@@ -525,15 +563,15 @@ VPRIVATE int APOLparm_parsePRESS(APOLparm *thee, Vio *sock) {
     if (sscanf(tok, "%lf", &tf) == 0) {
         Vnm_print(2, "NOsh:  Read non-float (%s) while parsing PRESS \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     }
     thee->press = tf;
     thee->setpress = 1;
-    return 1;
+    return VRC_SUCCESS;
 	
 VERROR1:
         Vnm_print(2, "parseAPOL:  ran out of tokens!\n");
-	return -1;
+	return VRC_WARNING;
 }
 
 VPUBLIC Vrc_Codes APOLparm_parseToken(APOLparm *thee, char tok[VMAX_BUFSIZE],
@@ -541,12 +579,12 @@ VPUBLIC Vrc_Codes APOLparm_parseToken(APOLparm *thee, char tok[VMAX_BUFSIZE],
 
     if (thee == VNULL) {
         Vnm_print(2, "parseAPOL:  got NULL thee!\n");
-        return -1;
+        return VRC_WARNING;
     }
 
     if (sock == VNULL) {
         Vnm_print(2, "parseAPOL:  got NULL socket!\n");
-        return -1;
+        return VRC_WARNING;
     }
 	
 	if (Vstring_strcasecmp(tok, "mol") == 0) {
@@ -556,11 +594,11 @@ VPUBLIC Vrc_Codes APOLparm_parseToken(APOLparm *thee, char tok[VMAX_BUFSIZE],
 	} else if (Vstring_strcasecmp(tok, "dime") == 0) {
 		Vnm_print(2, "APOLparm_parseToken:  The DIME and GLEN keywords for APOLAR have been replaced with GRID.\n");
 		Vnm_print(2, "APOLparm_parseToken:  Please see the APBS User Guide for more information.\n");
-		return -1;
+		return VRC_WARNING;
 	} else if (Vstring_strcasecmp(tok, "glen") == 0) {
 		Vnm_print(2, "APOLparm_parseToken:  The DIME and GLEN keywords for APOLAR have been replaced with GRID.\n");
 		Vnm_print(2, "APOLparm_parseToken:  Please see the APBS User Guide for more information.\n");
-		return -1;
+		return VRC_WARNING;
 	} else if (Vstring_strcasecmp(tok, "bconc") == 0) {
 		return APOLparm_parseBCONC(thee, sock);
     } else if (Vstring_strcasecmp(tok, "sdens") == 0) {
@@ -585,10 +623,10 @@ VPUBLIC Vrc_Codes APOLparm_parseToken(APOLparm *thee, char tok[VMAX_BUFSIZE],
         return APOLparm_parseCALCFORCE(thee, sock);
     } else {
         Vnm_print(2, "parseAPOL:  Unrecognized keyword (%s)!\n", tok);
-        return -1;
+        return VRC_WARNING;
     }
 	
     
-	return 0;
+	return VRC_FAILURE;
 
 }
