@@ -3,7 +3,7 @@
  *  @ingroup MGparm
  *  @author  Nathan Baker
  *  @brief   Class MGparm methods
- *  @version $Id: mgparm.c 1098 2007-06-13 15:50:28Z sobolevnrm $
+ *  @version $Id: mgparm.c 1251 2008-03-30 22:32:00Z sobolevnrm $
  *  @attention
  *  @verbatim
  *
@@ -16,50 +16,38 @@
  *
  * Additional contributing authors listed in the code documentation.
  *
- * Copyright (c) 2002-2007.  Washington University in St. Louis.
- * All Rights Reserved.
- * Portions Copyright (c) 1999-2002.  The Regents of the University of
- * California.  
- * Portions Copyright (c) 1995.  Michael Holst.
+ * Copyright (c) 2002-2008, Washington University in St. Louis.
+ * Portions Copyright (c) 2002-2008.  Nathan A. Baker
+ * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
+ * Portions Copyright (c) 1995.  Michael Holst
  *
- * This file is part of APBS.
- *
- * APBS is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * APBS is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with APBS; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
- *
- * Linking APBS statically or dynamically with other modules is making a
- * combined work based on APBS. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
+ * All rights reserved.
  * 
- * SPECIAL GPL EXCEPTION
- * In addition, as a special exception, the copyright holders of APBS
- * give you permission to combine the APBS program with free software
- * programs and libraries that are released under the GNU LGPL or with
- * code included in releases of ISIM, Ion Simulator Interface, PMV, PyMOL
- * SMOL, VMD, and Vision. Such combined software may be linked with APBS and 
- * redistributed together in original or modified form as mere aggregation
- * without requirement that the entire work be under the scope of the GNU 
- * General Public License. This special exception permission is also extended
- * to any software listed in the SPECIAL GPL EXCEPTION clauses by the PMG,
- * FEtk, MC, or MALOC libraries.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met: 
+ *
+ * -  Redistributions of source code must retain the above copyright notice, this
+ * list of conditions and the following disclaimer.  
  * 
- * Note that people who make modified versions of APBS are not obligated
- * to grant this special exception for their modified versions; it is
- * their choice whether to do so. The GNU General Public License gives
- * permission to release a modified version without this exception; this
- * exception also makes it possible to release a modified version which
- * carries forward this exception.
+ * - Redistributions in binary form must reproduce the above copyright notice,
+ * this list of conditions and the following disclaimer in the documentation
+ * and/or other materials provided with the distribution.
+ * 
+ * - Neither the name of Washington University in St. Louis nor the names of its
+ * contributors may be used to endorse or promote products derived from this
+ * software without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
+ * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
+ * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+ * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+ * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * @endverbatim
  */
@@ -70,7 +58,7 @@
 #include "apbs/mgparm.h"
 #include "apbs/vstring.h"
 
-VEMBED(rcsid="$Id: mgparm.c 1098 2007-06-13 15:50:28Z sobolevnrm $")
+VEMBED(rcsid="$Id: mgparm.c 1251 2008-03-30 22:32:00Z sobolevnrm $")
 
 #if !defined(VINLINE_MGPARM)
 
@@ -131,16 +119,16 @@ VPUBLIC MGparm* MGparm_ctor(MGparm_CalcType type) {
     MGparm *thee = VNULL;
     thee = Vmem_malloc(VNULL, 1, sizeof(MGparm));
     VASSERT( thee != VNULL);
-    VASSERT( MGparm_ctor2(thee, type) );
+    VASSERT( MGparm_ctor2(thee, type) == VRC_SUCCESS );
 
     return thee;
 }
 
-VPUBLIC int MGparm_ctor2(MGparm *thee, MGparm_CalcType type) {
+VPUBLIC Vrc_Codes MGparm_ctor2(MGparm *thee, MGparm_CalcType type) {
 
     int i;
 
-    if (thee == VNULL) return 0;
+    if (thee == VNULL) return VRC_FAILURE;
 
     for (i=0; i<3; i++) {
         thee->dime[i] = -1;
@@ -177,8 +165,11 @@ VPUBLIC int MGparm_ctor2(MGparm *thee, MGparm_CalcType type) {
 
     /* *** Default parameters for TINKER *** */
     thee->chgs = VCM_CHARGE;
-
-    return 1; 
+	
+	thee->useAqua = 0; 
+	thee->setUseAqua = 0;
+	
+    return VRC_SUCCESS; 
 }
 
 VPUBLIC void MGparm_dtor(MGparm **thee) {
@@ -191,9 +182,10 @@ VPUBLIC void MGparm_dtor(MGparm **thee) {
 
 VPUBLIC void MGparm_dtor2(MGparm *thee) { ; }
 
-VPUBLIC int MGparm_check(MGparm *thee) { 
+VPUBLIC Vrc_Codes MGparm_check(MGparm *thee) { 
 
-    int rc, i, tdime[3], ti, tnlev[3], nlev;
+    Vrc_Codes rc;
+	int i, tdime[3], ti, tnlev[3], nlev;
 
     rc = VRC_SUCCESS;
 	
@@ -278,7 +270,8 @@ VPUBLIC int MGparm_check(MGparm *thee) {
 	/* Calculate the actual number of grid points and nlev to satisfy the
 	 * formula:  n = c * 2^(l+1) + 1, where n is the number of grid points,
 	 * c is an integer, and l is the number of levels */
-        for (i=0; i<3; i++) {
+	if (thee->type != MCT_DUMMY) {
+		for (i=0; i<3; i++) {
             /* See if the user picked a reasonable value, if not then fix it */
             ti = thee->dime[i] - 1;
             if (ti == VPOW(2, (thee->nlev+1))) {
@@ -309,6 +302,17 @@ VPUBLIC int MGparm_check(MGparm *thee) {
                 }
             }
         }
+	} else { /* We are a dummy calculation, but we still need positive numbers of points */
+		for (i=0; i<3; i++) {
+		    tnlev[i] = thee->nlev;
+			tdime[i] = thee->dime[i];
+				if (thee->dime[i] <= 0) {
+					Vnm_print(2, "NOsh:  Resetting dime[%d] from %d to 3.\n", i, thee->dime[i]);
+					thee->dime[i] = 3;
+			}
+		}
+	}
+	
 	/* The actual number of levels we'll be using is the smallest number of
          * possible levels in any dimensions */
         nlev = VMIN2(tnlev[0], tnlev[1]);
@@ -328,7 +332,9 @@ VPUBLIC int MGparm_check(MGparm *thee) {
 		}
         for (i=0; i<3; i++) thee->dime[i] = tdime[i];
     }
-
+	
+	if (!thee->setUseAqua) thee->useAqua = 0;
+	
     return rc;
 }
 
@@ -393,10 +399,18 @@ VPUBLIC void MGparm_copy(MGparm *thee, MGparm *parm) {
     thee->setofrac = parm->setofrac;
 	thee->setasync = parm->setasync;
 	thee->async = parm->async;
-
+	
+	thee->nonlintype = parm->nonlintype;
+	thee->setnonlintype = parm->setnonlintype;
+	
+	thee->method = parm->method;
+	thee->method = parm->method;
+	
+	thee->useAqua = parm->useAqua;
+	thee->setUseAqua = parm->setUseAqua;
 }
 
-VPRIVATE int MGparm_parseDIME(MGparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes MGparm_parseDIME(MGparm *thee, Vio *sock) {
 
     char tok[VMAX_BUFSIZE];
     int ti;
@@ -405,29 +419,29 @@ VPRIVATE int MGparm_parseDIME(MGparm *thee, Vio *sock) {
     if (sscanf(tok, "%d", &ti) == 0){
         Vnm_print(2, "parseMG:  Read non-integer (%s) while parsing DIME \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     } else thee->dime[0] = ti;
     VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
     if (sscanf(tok, "%d", &ti) == 0) {
         Vnm_print(2, "NOsh:  Read non-integer (%s) while parsing DIME \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     } else thee->dime[1] = ti;
     VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
     if (sscanf(tok, "%d", &ti) == 0) {
         Vnm_print(2, "NOsh:  Read non-integer (%s) while parsing DIME \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     } else thee->dime[2] = ti;
     thee->setdime = 1;
-    return 1;
+    return VRC_SUCCESS;
 
     VERROR1:
         Vnm_print(2, "parseMG:  ran out of tokens!\n");
-        return -1;
+        return VRC_WARNING;
 }
 
-VPRIVATE int MGparm_parseCHGM(MGparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes MGparm_parseCHGM(MGparm *thee, Vio *sock) {
 
     char tok[VMAX_BUFSIZE];
     int ti;
@@ -453,32 +467,32 @@ VPRIVATE int MGparm_parseCHGM(MGparm *thee, Vio *sock) {
                 break;
         }
         Vnm_print(2, "\" instead!\n");
-        return 1;
+        return VRC_SUCCESS;
     } else if (Vstring_strcasecmp(tok, "spl0") == 0) {
         thee->chgm = VCM_TRIL;
         thee->setchgm = 1;
-        return 1;
+        return VRC_SUCCESS;
     } else if (Vstring_strcasecmp(tok, "spl2") == 0) {
         thee->chgm = VCM_BSPL2;
         thee->setchgm = 1;
-        return 1;
+        return VRC_SUCCESS;
     } else if (Vstring_strcasecmp(tok, "spl4") == 0) {
         thee->chgm = VCM_BSPL4;
         thee->setchgm = 1;
-        return 1;
+        return VRC_SUCCESS;
     } else {
         Vnm_print(2, "NOsh:  Unrecognized parameter (%s) when parsing \
 chgm!\n", tok);
-        return -1;
+        return VRC_WARNING;
     }
-    return -1;
+    return VRC_WARNING;
 
     VERROR1:
         Vnm_print(2, "parseMG:  ran out of tokens!\n");
-        return -1;
+        return VRC_WARNING;
 }
 
-VPRIVATE int MGparm_parseNLEV(MGparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes MGparm_parseNLEV(MGparm *thee, Vio *sock) {
 
     char tok[VMAX_BUFSIZE];
     int ti;
@@ -487,17 +501,17 @@ VPRIVATE int MGparm_parseNLEV(MGparm *thee, Vio *sock) {
     if (sscanf(tok, "%d", &ti) == 0) {
         Vnm_print(2, "NOsh:  Read non-integer (%s) while parsing NLEV \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     } else thee->nlev = ti;
     thee->setnlev = 1;
-    return 1;
+    return VRC_SUCCESS;
 
     VERROR1:
         Vnm_print(2, "parseMG:  ran out of tokens!\n");
-        return -1;
+        return VRC_WARNING;
 }
 
-VPRIVATE int MGparm_parseGRID(MGparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes MGparm_parseGRID(MGparm *thee, Vio *sock) {
 
     char tok[VMAX_BUFSIZE];
     double tf;
@@ -506,29 +520,29 @@ VPRIVATE int MGparm_parseGRID(MGparm *thee, Vio *sock) {
     if (sscanf(tok, "%lf", &tf) == 0) {
         Vnm_print(2, "NOsh:  Read non-float (%s) while parsing GRID \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     } else thee->grid[0] = tf;
     VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
     if (sscanf(tok, "%lf", &tf) == 0) {
         Vnm_print(2, "NOsh:  Read non-float (%s) while parsing GRID \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     } else thee->grid[1] = tf;
     VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
     if (sscanf(tok, "%lf", &tf) == 0) {
         Vnm_print(2, "NOsh:  Read non-float (%s) while parsing GRID \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     } else thee->grid[2] = tf;
     thee->setgrid = 1;
-    return 1;
+    return VRC_SUCCESS;
 
     VERROR1:
         Vnm_print(2, "parseMG:  ran out of tokens!\n");
-        return -1;
+        return VRC_WARNING;
 }
 
-VPRIVATE int MGparm_parseGLEN(MGparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes MGparm_parseGLEN(MGparm *thee, Vio *sock) {
 
     char tok[VMAX_BUFSIZE];
     double tf;
@@ -537,43 +551,43 @@ VPRIVATE int MGparm_parseGLEN(MGparm *thee, Vio *sock) {
     if (sscanf(tok, "%lf", &tf) == 0) {
         Vnm_print(2, "NOsh:  Read non-float (%s) while parsing GLEN \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     } else thee->glen[0] = tf;
     VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
     if (sscanf(tok, "%lf", &tf) == 0) {
         Vnm_print(2, "NOsh:  Read non-float (%s) while parsing GLEN \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     } else thee->glen[1] = tf;
     VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
     if (sscanf(tok, "%lf", &tf) == 0) {
         Vnm_print(2, "NOsh:  Read non-float (%s) while parsing GLEN \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     } else thee->glen[2] = tf;
     thee->setglen = 1;
-    return 1;
+    return VRC_SUCCESS;
 
     VERROR1:
         Vnm_print(2, "parseMG:  ran out of tokens!\n");
-        return -1;
+        return VRC_WARNING;
 }
 
-VPRIVATE int MGparm_parseGAMMA(MGparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes MGparm_parseGAMMA(MGparm *thee, Vio *sock) {
 	
     char tok[VMAX_BUFSIZE];
 	
     VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
 	Vnm_print(2, "parseMG:  GAMMA keyword deprecated!\n");
 	Vnm_print(2, "parseMG:  Please see new APOLAR documentation.\n");
-	return 1;
+	return VRC_SUCCESS;
 	
 VERROR1:
         Vnm_print(2, "parseMG:  ran out of tokens!\n");
-	return -1;
+	return VRC_WARNING;
 }
 
-VPRIVATE int MGparm_parseGCENT(MGparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes MGparm_parseGCENT(MGparm *thee, Vio *sock) {
 
     char tok[VMAX_BUFSIZE];
     double tf;
@@ -588,7 +602,7 @@ VPRIVATE int MGparm_parseGCENT(MGparm *thee, Vio *sock) {
             if (sscanf(tok, "%d", &ti) == 0) {
                 Vnm_print(2, "NOsh:  Read non-int (%s) while parsing \
 GCENT MOL keyword!\n", tok);
-                return -1;
+                return VRC_WARNING;
             } else {
                 thee->cmeth = MCM_MOLECULE;
 				/* Subtract 1 here to convert user numbering (1, 2, 3, ...) into
@@ -598,7 +612,7 @@ GCENT MOL keyword!\n", tok);
         } else {
             Vnm_print(2, "NOsh:  Unexpected keyword (%s) while parsing \
 GCENT!\n", tok);
-            return -1;
+            return VRC_WARNING;
         }
     } else {
         thee->center[0] = tf;
@@ -606,26 +620,26 @@ GCENT!\n", tok);
         if (sscanf(tok, "%lf", &tf) == 0) {
             Vnm_print(2, "NOsh:  Read non-float (%s) while parsing \
 GCENT keyword!\n", tok);
-            return -1;
+            return VRC_WARNING;
         }
         thee->center[1] = tf;
         VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
         if (sscanf(tok, "%lf", &tf) == 0) {
             Vnm_print(2, "NOsh:  Read non-float (%s) while parsing \
 GCENT keyword!\n", tok);
-            return -1;
+            return VRC_WARNING;
         } 
         thee->center[2] = tf;
     }
     thee->setgcent = 1;
-    return 1;
+    return VRC_SUCCESS;
 
     VERROR1:
         Vnm_print(2, "parseMG:  ran out of tokens!\n");
-        return -1;
+        return VRC_WARNING;
 }
 
-VPRIVATE int MGparm_parseCGLEN(MGparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes MGparm_parseCGLEN(MGparm *thee, Vio *sock) {
 
     char tok[VMAX_BUFSIZE];
     double tf;
@@ -634,29 +648,29 @@ VPRIVATE int MGparm_parseCGLEN(MGparm *thee, Vio *sock) {
     if (sscanf(tok, "%lf", &tf) == 0) {
         Vnm_print(2, "NOsh:  Read non-float (%s) while parsing CGLEN \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     } else thee->cglen[0] = tf;
     VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
     if (sscanf(tok, "%lf", &tf) == 0) {
         Vnm_print(2, "NOsh:  Read non-float (%s) while parsing CGLEN \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     } else thee->cglen[1] = tf;
     VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
     if (sscanf(tok, "%lf", &tf) == 0) {
         Vnm_print(2, "NOsh:  Read non-float (%s) while parsing CGLEN \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     } else thee->cglen[2] = tf;
     thee->setcglen = 1;
-    return 1;
+    return VRC_SUCCESS;
 
     VERROR1:
         Vnm_print(2, "parseMG:  ran out of tokens!\n");
-        return -1;
+        return VRC_WARNING;
 }
 
-VPRIVATE int MGparm_parseFGLEN(MGparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes MGparm_parseFGLEN(MGparm *thee, Vio *sock) {
 
     char tok[VMAX_BUFSIZE];
     double tf;
@@ -665,29 +679,29 @@ VPRIVATE int MGparm_parseFGLEN(MGparm *thee, Vio *sock) {
     if (sscanf(tok, "%lf", &tf) == 0) {
         Vnm_print(2, "NOsh:  Read non-float (%s) while parsing FGLEN \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     } else thee->fglen[0] = tf;
     VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
     if (sscanf(tok, "%lf", &tf) == 0) {
         Vnm_print(2, "NOsh:  Read non-float (%s) while parsing FGLEN \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     } else thee->fglen[1] = tf;
     VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
     if (sscanf(tok, "%lf", &tf) == 0) {
         Vnm_print(2, "NOsh:  Read non-float (%s) while parsing FGLEN \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     } else thee->fglen[2] = tf;
     thee->setfglen = 1;
-    return 1;
+    return VRC_SUCCESS;
 
     VERROR1:
         Vnm_print(2, "parseMG:  ran out of tokens!\n");
-        return -1;
+        return VRC_WARNING;
 }
 
-VPRIVATE int MGparm_parseCGCENT(MGparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes MGparm_parseCGCENT(MGparm *thee, Vio *sock) {
 
     char tok[VMAX_BUFSIZE];
     double tf;
@@ -702,7 +716,7 @@ VPRIVATE int MGparm_parseCGCENT(MGparm *thee, Vio *sock) {
             if (sscanf(tok, "%d", &ti) == 0) {
                 Vnm_print(2, "NOsh:  Read non-int (%s) while parsing \
 CGCENT MOL keyword!\n", tok);
-                return -1;
+                return VRC_WARNING;
             } else {
 				thee->ccmeth = MCM_MOLECULE;
 				/* Subtract 1 here to convert user numbering (1, 2, 3, ...) into 
@@ -712,7 +726,7 @@ CGCENT MOL keyword!\n", tok);
         } else {
             Vnm_print(2, "NOsh:  Unexpected keyword (%s) while parsing \
 CGCENT!\n", tok);
-            return -1;
+            return VRC_WARNING;
             }
     } else {
         thee->ccenter[0] = tf;
@@ -720,26 +734,26 @@ CGCENT!\n", tok);
         if (sscanf(tok, "%lf", &tf) == 0) {
             Vnm_print(2, "NOsh:  Read non-float (%s) while parsing \
 CGCENT keyword!\n", tok);
-            return -1;
+            return VRC_WARNING;
         }
         thee->ccenter[1] = tf;
         VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
         if (sscanf(tok, "%lf", &tf) == 0) {
             Vnm_print(2, "NOsh:  Read non-float (%s) while parsing \
 CGCENT keyword!\n", tok);
-            return -1;
+            return VRC_WARNING;
         }
         thee->ccenter[2] = tf;
     }
     thee->setcgcent = 1;
-    return 1;
+    return VRC_SUCCESS;
 
     VERROR1:
         Vnm_print(2, "parseMG:  ran out of tokens!\n");
-        return -1;
+        return VRC_WARNING;
 }
 
-VPRIVATE int MGparm_parseFGCENT(MGparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes MGparm_parseFGCENT(MGparm *thee, Vio *sock) {
 
     char tok[VMAX_BUFSIZE];
     double tf;
@@ -754,7 +768,7 @@ VPRIVATE int MGparm_parseFGCENT(MGparm *thee, Vio *sock) {
             if (sscanf(tok, "%d", &ti) == 0) {
                  Vnm_print(2, "NOsh:  Read non-int (%s) while parsing \
 FGCENT MOL keyword!\n", tok);
-                 return -1;
+                 return VRC_WARNING;
             } else {
                 thee->fcmeth = MCM_MOLECULE;
 				/* Subtract 1 here to convert user numbering (1, 2, 3, ...) into
@@ -764,7 +778,7 @@ FGCENT MOL keyword!\n", tok);
         } else {
             Vnm_print(2, "NOsh:  Unexpected keyword (%s) while parsing \
 FGCENT!\n", tok);
-            return -1;
+            return VRC_WARNING;
         }
     } else {
         thee->fcenter[0] = tf;
@@ -772,26 +786,26 @@ FGCENT!\n", tok);
         if (sscanf(tok, "%lf", &tf) == 0) {
             Vnm_print(2, "NOsh:  Read non-float (%s) while parsing \
 FGCENT keyword!\n", tok);
-            return -1;
+            return VRC_WARNING;
         }
         thee->fcenter[1] = tf;
         VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
         if (sscanf(tok, "%lf", &tf) == 0) {
             Vnm_print(2, "NOsh:  Read non-float (%s) while parsing \
 FGCENT keyword!\n", tok);
-            return -1;
+            return VRC_WARNING;
         }
         thee->fcenter[2] = tf;
     }
     thee->setfgcent = 1;
-    return 1;
+    return VRC_SUCCESS;
 
     VERROR1:
         Vnm_print(2, "parseMG:  ran out of tokens!\n");
-        return -1;
+        return VRC_WARNING;
 }
 
-VPRIVATE int MGparm_parsePDIME(MGparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes MGparm_parsePDIME(MGparm *thee, Vio *sock) {
 
     char tok[VMAX_BUFSIZE];
     int ti;
@@ -801,7 +815,7 @@ VPRIVATE int MGparm_parsePDIME(MGparm *thee, Vio *sock) {
     if (sscanf(tok, "%d", &ti) == 0) {
         Vnm_print(2, "NOsh:  Read non-integer (%s) while parsing PDIME \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     } else {
         thee->pdime[0] = ti;
     }
@@ -809,7 +823,7 @@ keyword!\n", tok);
     if (sscanf(tok, "%d", &ti) == 0) {
         Vnm_print(2, "NOsh:  Read non-integer (%s) while parsing PDIME \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     } else {
         thee->pdime[1] = ti;
     }
@@ -817,19 +831,19 @@ keyword!\n", tok);
     if (sscanf(tok, "%d", &ti) == 0) {
         Vnm_print(2, "NOsh:  Read non-integer (%s) while parsing PDIME \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     } else {
         thee->pdime[2] = ti;
     }
     thee->setpdime = 1;
-    return 1;
+    return VRC_SUCCESS;
 
     VERROR1:
         Vnm_print(2, "parseMG:  ran out of tokens!\n");
-        return -1;
+        return VRC_WARNING;
 }
 
-VPRIVATE int MGparm_parseOFRAC(MGparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes MGparm_parseOFRAC(MGparm *thee, Vio *sock) {
 
     char tok[VMAX_BUFSIZE];
     double tf;
@@ -838,18 +852,18 @@ VPRIVATE int MGparm_parseOFRAC(MGparm *thee, Vio *sock) {
     if (sscanf(tok, "%lf", &tf) == 0) {
         Vnm_print(2, "NOsh:  Read non-int (%s) while parsing OFRAC \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     }
     thee->ofrac = tf;
     thee->setofrac = 1;
-    return 1;
+    return VRC_SUCCESS;
 
     VERROR1:
         Vnm_print(2, "parseMG:  ran out of tokens!\n");
-        return -1;
+        return VRC_WARNING;
 }
 
-VPRIVATE int MGparm_parseASYNC(MGparm *thee, Vio *sock) {
+VPRIVATE Vrc_Codes MGparm_parseASYNC(MGparm *thee, Vio *sock) {
 
     char tok[VMAX_BUFSIZE];
     int ti;
@@ -858,27 +872,34 @@ VPRIVATE int MGparm_parseASYNC(MGparm *thee, Vio *sock) {
     if (sscanf(tok, "%i", &ti) == 0) {
         Vnm_print(2, "NOsh:  Read non-integer (%s) while parsing ASYNC \
 keyword!\n", tok);
-        return -1;
+        return VRC_WARNING;
     }
     thee->async = ti;
     thee->setasync = 1;
-    return 1;
+    return VRC_SUCCESS;
 
     VERROR1:
         Vnm_print(2, "parseMG:  ran out of tokens!\n");
-        return -1;
+        return VRC_WARNING;
 }
 
-VPUBLIC int MGparm_parseToken(MGparm *thee, char tok[VMAX_BUFSIZE], 
+VPRIVATE int MGparm_parseUSEAQUA(MGparm *thee, Vio *sock) {
+    Vnm_print(0, "NOsh: parsed useaqua\n");
+    thee->useAqua = 1;
+    thee->setUseAqua = 1;
+    return 1;
+}
+
+VPUBLIC Vrc_Codes MGparm_parseToken(MGparm *thee, char tok[VMAX_BUFSIZE], 
   Vio *sock) {
 
     if (thee == VNULL) {
         Vnm_print(2, "parseMG:  got NULL thee!\n"); 
-        return -1;
+        return VRC_WARNING;
     }
     if (sock == VNULL) {
         Vnm_print(2, "parseMG:  got NULL socket!\n"); 
-        return -1;
+        return VRC_WARNING;
     }
 	
 	Vnm_print(0, "MGparm_parseToken:  trying %s...\n", tok);
@@ -912,11 +933,13 @@ VPUBLIC int MGparm_parseToken(MGparm *thee, char tok[VMAX_BUFSIZE],
         return MGparm_parseASYNC(thee, sock);
 	} else if (Vstring_strcasecmp(tok, "gamma") == 0) {
         return MGparm_parseGAMMA(thee, sock);
+	} else if (Vstring_strcasecmp(tok, "useaqua") == 0) {
+        return MGparm_parseUSEAQUA(thee, sock);
     } else {
         Vnm_print(2, "parseMG:  Unrecognized keyword (%s)!\n", tok);
-        return -1;
+        return VRC_WARNING;
     }
    
-    return 0;
+    return VRC_FAILURE;
 
 }
