@@ -3,7 +3,7 @@
  *  @ingroup NOsh
  *  @author  Nathan Baker
  *  @brief   Class NOsh methods
- *  @version $Id: nosh.c 1098 2007-06-13 15:50:28Z sobolevnrm $
+ *  @version $Id: nosh.c 1251 2008-03-30 22:32:00Z sobolevnrm $
  *  @attention
  *  @verbatim
  *
@@ -16,50 +16,38 @@
  *
  * Additional contributing authors listed in the code documentation.
  *
- * Copyright (c) 2002-2007.  Washington University in St. Louis.
- * All Rights Reserved.
- * Portions Copyright (c) 1999-2002.  The Regents of the University of
- * California.  
- * Portions Copyright (c) 1995.  Michael Holst.
+ * Copyright (c) 2002-2008, Washington University in St. Louis.
+ * Portions Copyright (c) 2002-2008.  Nathan A. Baker
+ * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
+ * Portions Copyright (c) 1995.  Michael Holst
  *
- * This file is part of APBS.
- *
- * APBS is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * APBS is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with APBS; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
- *
- * Linking APBS statically or dynamically with other modules is making a
- * combined work based on APBS. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
+ * All rights reserved.
  * 
- * SPECIAL GPL EXCEPTION
- * In addition, as a special exception, the copyright holders of APBS
- * give you permission to combine the APBS program with free software
- * programs and libraries that are released under the GNU LGPL or with
- * code included in releases of ISIM, Ion Simulator Interface, PMV, PyMOL
- * SMOL, VMD, and Vision. Such combined software may be linked with APBS and 
- * redistributed together in original or modified form as mere aggregation
- * without requirement that the entire work be under the scope of the GNU 
- * General Public License. This special exception permission is also extended
- * to any software listed in the SPECIAL GPL EXCEPTION clauses by the PMG,
- * FEtk, MC, or MALOC libraries.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met: 
+ *
+ * -  Redistributions of source code must retain the above copyright notice, this
+ * list of conditions and the following disclaimer.  
  * 
- * Note that people who make modified versions of APBS are not obligated
- * to grant this special exception for their modified versions; it is
- * their choice whether to do so. The GNU General Public License gives
- * permission to release a modified version without this exception; this
- * exception also makes it possible to release a modified version which
- * carries forward this exception.
+ * - Redistributions in binary form must reproduce the above copyright notice,
+ * this list of conditions and the following disclaimer in the documentation
+ * and/or other materials provided with the distribution.
+ * 
+ * - Neither the name of Washington University in St. Louis nor the names of its
+ * contributors may be used to endorse or promote products derived from this
+ * software without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
+ * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
+ * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+ * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+ * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * @endverbatim
  */
@@ -71,7 +59,7 @@
 #include "apbs/mgparm.h"
 #include "apbs/femparm.h"
 
-VEMBED(rcsid="$Id: nosh.c 1098 2007-06-13 15:50:28Z sobolevnrm $")
+VEMBED(rcsid="$Id: nosh.c 1251 2008-03-30 22:32:00Z sobolevnrm $")
 
 
 VPRIVATE int NOsh_parseREAD(
@@ -305,6 +293,7 @@ VPUBLIC void NOsh_dtor2(NOsh *thee) {
 	if (thee != VNULL) {
 		for (i=0; i<(thee->ncalc); i++) NOsh_calc_dtor(&(thee->calc[i]));
 		for (i=0; i<(thee->nelec); i++) NOsh_calc_dtor(&(thee->elec[i]));
+		for (i=0; i<(thee->napol); i++) NOsh_calc_dtor(&(thee->apol[i]));
     }
 	
 }
@@ -412,7 +401,7 @@ VPUBLIC int NOsh_parseInput(
 							Vio *sock
 							) {
 	
-	char *MCwhiteChars = " =,;\t\n";
+	char *MCwhiteChars = " =,;\t\r\n";
 	char *MCcommChars  = "#%";
 	char tok[VMAX_BUFSIZE];
 	
@@ -669,6 +658,35 @@ section!\n");
 	
 }
 
+VPRIVATE int NOsh_parseREAD_MESH(NOsh *thee, Vio *sock) {
+	
+    char tok[VMAX_BUFSIZE];
+    Vdata_Format meshfmt;
+	
+    VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
+    if (Vstring_strcasecmp(tok, "mcsf") == 0) {
+        meshfmt = VDF_MCSF;
+        VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
+        Vnm_print(0, "NOsh: Storing mesh %d path %s\n",
+				  thee->nmesh, tok);
+        thee->meshfmt[thee->nmesh] = meshfmt;
+        strncpy(thee->meshpath[thee->nmesh], tok, VMAX_ARGLEN);
+        (thee->nmesh)++;
+    } else {
+        Vnm_print(2, "NOsh_parseREAD:  Ignoring undefined mesh format \
+				  %s!\n", tok);
+    }
+	
+    return 1;
+	
+VERROR1:
+	Vnm_print(2, "NOsh_parseREAD:  Ran out of tokens while parsing READ \
+			  section!\n");
+	return 0;
+	
+}
+
+
 VPRIVATE int NOsh_parseREAD(NOsh *thee, Vio *sock) {
 	
     char tok[VMAX_BUFSIZE];
@@ -704,6 +722,8 @@ VPRIVATE int NOsh_parseREAD(NOsh *thee, Vio *sock) {
             NOsh_parseREAD_KAPPA(thee,sock);
         } else if (Vstring_strcasecmp(tok, "charge") == 0) {
             NOsh_parseREAD_CHARGE(thee,sock);
+		} else if (Vstring_strcasecmp(tok, "mesh") == 0) {
+			NOsh_parseREAD_MESH(thee,sock);
         } else {
             Vnm_print(2, "NOsh_parseREAD:  Ignoring undefined keyword %s!\n", 
 					  tok);
@@ -1939,6 +1959,7 @@ VPUBLIC int NOsh_parseFEM(
 	FEMparm *feparm = VNULL;    
 	PBEparm *pbeparm = VNULL;    
 	int rc;
+	Vrc_Codes vrc;
 	
 	/* Check the arguments */
 	if (thee == VNULL) {
@@ -1987,11 +2008,11 @@ VPUBLIC int NOsh_parseFEM(
 			break;
 		} else if (rc == 0) {
 			/* Pass the token to the generic MG parser */
-			rc = FEMparm_parseToken(feparm, tok, sock);
-			if (rc == -1) { 
+			vrc = FEMparm_parseToken(feparm, tok, sock);
+			if (vrc == VRC_FAILURE) { 
 				Vnm_print(0, "NOsh_parseFEM:  parseMG error!\n");
 				break;
-			} else if (rc == 0) {
+			} else if (vrc == VRC_WARNING) {
 				/* We ran out of parsers! */
 				Vnm_print(2, "NOsh:  Unrecognized keyword: %s\n", tok);
 				break;
