@@ -3,7 +3,7 @@
  *  @ingroup PBEparm
  *  @author  Nathan Baker
  *  @brief   Class PBEparm methods
- *  @version $Id: pbeparm.c 1102 2007-07-03 13:31:56Z sobolevnrm $
+ *  @version $Id: pbeparm.c 1252 2008-04-01 14:30:41Z sdg0919 $
  *  @attention
  *  @verbatim
  *
@@ -16,50 +16,38 @@
  *
  * Additional contributing authors listed in the code documentation.
  *
- * Copyright (c) 2002-2007.  Washington University in St. Louis.
- * All Rights Reserved.
- * Portions Copyright (c) 1999-2002.  The Regents of the University of
- * California.  
- * Portions Copyright (c) 1995.  Michael Holst.
+ * Copyright (c) 2002-2008, Washington University in St. Louis.
+ * Portions Copyright (c) 2002-2008.  Nathan A. Baker
+ * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
+ * Portions Copyright (c) 1995.  Michael Holst
  *
- * This file is part of APBS.
- *
- * APBS is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * APBS is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with APBS; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
- *
- * Linking APBS statically or dynamically with other modules is making a
- * combined work based on APBS. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
+ * All rights reserved.
  * 
- * SPECIAL GPL EXCEPTION
- * In addition, as a special exception, the copyright holders of APBS
- * give you permission to combine the APBS program with free software
- * programs and libraries that are released under the GNU LGPL or with
- * code included in releases of ISIM, Ion Simulator Interface, PMV, PyMOL
- * SMOL, VMD, and Vision. Such combined software may be linked with APBS and 
- * redistributed together in original or modified form as mere aggregation
- * without requirement that the entire work be under the scope of the GNU 
- * General Public License. This special exception permission is also extended
- * to any software listed in the SPECIAL GPL EXCEPTION clauses by the PMG,
- * FEtk, MC, or MALOC libraries.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met: 
+ *
+ * -  Redistributions of source code must retain the above copyright notice, this
+ * list of conditions and the following disclaimer.  
  * 
- * Note that people who make modified versions of APBS are not obligated
- * to grant this special exception for their modified versions; it is
- * their choice whether to do so. The GNU General Public License gives
- * permission to release a modified version without this exception; this
- * exception also makes it possible to release a modified version which
- * carries forward this exception.
+ * - Redistributions in binary form must reproduce the above copyright notice,
+ * this list of conditions and the following disclaimer in the documentation
+ * and/or other materials provided with the distribution.
+ * 
+ * - Neither the name of Washington University in St. Louis nor the names of its
+ * contributors may be used to endorse or promote products derived from this
+ * software without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
+ * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
+ * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+ * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+ * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * @endverbatim
  */
@@ -68,7 +56,7 @@
 #include "apbs/pbeparm.h"
 #include "apbs/vstring.h"
 
-VEMBED(rcsid="$Id: pbeparm.c 1102 2007-07-03 13:31:56Z sobolevnrm $")
+VEMBED(rcsid="$Id: pbeparm.c 1252 2008-04-01 14:30:41Z sdg0919 $")
 
 #if !defined(VINLINE_MGPARM)
 
@@ -101,7 +89,7 @@ VPUBLIC PBEparm* PBEparm_ctor() {
     VASSERT( PBEparm_ctor2(thee) );
 
     return thee;
-}
+} 
 
 VPUBLIC int PBEparm_ctor2(PBEparm *thee) {
 
@@ -232,7 +220,7 @@ VPUBLIC int PBEparm_check(PBEparm *thee) {
     if (!thee->setcalcenergy) thee->calcenergy = PCE_NO;
     if (!thee->setcalcforce) thee->calcforce = PCF_NO;
     if (!thee->setwritemat) thee->writemat = 0;
-
+	
     return 1;
 }
 
@@ -351,21 +339,45 @@ VPRIVATE int PBEparm_parseNRPBE(PBEparm *thee, Vio *sock) {
 }
 
 VPRIVATE int PBEparm_parseSMPBE(PBEparm *thee, Vio *sock) {
-	char sizeTok[VMAX_BUFSIZE];
-	char volTok[VMAX_BUFSIZE];
+
+	int i;
+	
+	char type[VMAX_BUFSIZE]; /* vol or size (keywords) */
+	char value[VMAX_BUFSIZE]; /* floating point value */
+	
+	char setVol = 1;
+	char setSize = 1;
+	char keyValuePairs = 2;
+	
     double size, volume;
 	
-	VJMPERR1(Vio_scanf(sock, "%s", volTok) == 1);
-    if (sscanf(volTok, "%lf", &volume) == 0) {
-        Vnm_print(2, "NOsh:  Read non-float (%s) while parsing smpbe keyword!\n", volTok);
-        return -1;
-    }
+	for(i=0;i<keyValuePairs;i++){
+		
+		/* The line two tokens at a time */
+		VJMPERR1(Vio_scanf(sock, "%s", type) == 1);
+		VJMPERR1(Vio_scanf(sock, "%s", value) == 1);
+		
+		if(!strcmp(type,"vol")){
+			if ((setVol = sscanf(value, "%lf", &volume)) == 0){
+				Vnm_print(2,"NOsh:  Read non-float (%s) while parsing smpbe keyword!\n", value);
+				return VRC_FAILURE;
+			}
+		}else if(!strcmp(type,"size")){
+			if ((setSize = sscanf(value, "%lf", &size)) == 0){
+				Vnm_print(2,"NOsh:  Read non-float (%s) while parsing smpbe keyword!\n", value);
+				return VRC_FAILURE;
+			}
+		}else{
+			Vnm_print(2,"NOsh:  Read non-float (%s) while parsing smpbe keyword!\n", value);
+			return VRC_FAILURE;
+		}
+	}
 	
-    VJMPERR1(Vio_scanf(sock, "%s", sizeTok) == 1);
-    if (sscanf(sizeTok, "%lf", &size) == 0) {
-        Vnm_print(2, "NOsh:  Read non-float (%s) while parsing smpbe keyword!\n", sizeTok);
-        return -1;
-    }
+	/* If either the volume or size isn't set, throw an error */
+	if((setVol == 0) || (setSize == 0)){
+		Vnm_print(2,"NOsh:  Error while parsing smpbe keywords! Only size or vol was specified.\n");
+		return VRC_FAILURE;
+	}
 	
 	Vnm_print(0, "NOsh: parsed smpbe\n");
     thee->pbetype = PBE_SMPBE;
@@ -377,11 +389,11 @@ VPRIVATE int PBEparm_parseSMPBE(PBEparm *thee, Vio *sock) {
 	thee->smvolume = volume;
 	thee->setsmvolume = 1;
 	
-    return 1;
+	return VRC_SUCCESS;
 	
 VERROR1:
     Vnm_print(2, "parsePBE:  ran out of tokens!\n");
-	return -1;
+	return VRC_FAILURE;
 	
 }
 
@@ -453,38 +465,100 @@ statement\n", ti);
 }
 
 VPRIVATE int PBEparm_parseION(PBEparm *thee, Vio *sock) {
-    char tok[VMAX_BUFSIZE];
-    double tf;
-
+    
+	int i;
+	int meth = 0;
+	
+	char tok[VMAX_BUFSIZE];
+	char value[VMAX_BUFSIZE];
+	
+	double tf;
+	double charge, conc, radius;
+	
+	int setCharge = 0;
+	int setConc = 0;
+	int setRadius = 0;
+	int keyValuePairs = 3;
+	
+	/* Get the initial token for the ION statement */
     VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
-    if (sscanf(tok, "%lf", &tf) == 0) {
-        Vnm_print(2, "NOsh:  Read non-float (%s) while parsing ION \
-keyword!\n", tok);
-        return -1;
-    }
-    thee->ionq[thee->nion] = tf;
-    VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
-    if (sscanf(tok, "%lf", &tf) == 0) {
-        Vnm_print(2, "NOsh:  Read non-float (%s) while parsing ION \
-keyword!\n", tok);
-        return -1;
-    }
-    thee->ionc[thee->nion] = tf;
-    VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
-    if (sscanf(tok, "%lf", &tf) == 0) {
-        Vnm_print(2, "NOsh:  Read non-float (%s) while parsing ION \
-keyword!\n", tok);
-        return -1;
-    }
-    thee->ionr[thee->nion] = tf;
-    thee->setion[thee->nion] = 1;
-    (thee->nion)++;
-    thee->setnion = 1;
-    return 1;
-
+	
+	/* Scan the token once to determine the type (old style or new keyValue pair) */
+	meth = sscanf(tok, "%lf", &tf);
+	/* If tok is a non-zero float value, we are using the old method */
+	if(meth != 0){
+		
+		Vnm_print(2, "NOsh:  Deprecated use of ION keyword! Use key-value pairs\n", tok);
+		
+		if (sscanf(tok, "%lf", &tf) == 0) {
+			Vnm_print(2, "NOsh:  Read non-float (%s) while parsing ION keyword!\n", tok);
+			return VRC_FAILURE;
+		}
+		thee->ionq[thee->nion] = tf;
+		VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
+		if (sscanf(tok, "%lf", &tf) == 0) {
+			Vnm_print(2, "NOsh:  Read non-float (%s) while parsing ION keyword!\n", tok);
+			return VRC_FAILURE;
+		}
+		thee->ionc[thee->nion] = tf;
+		VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
+		if (sscanf(tok, "%lf", &tf) == 0) {
+			Vnm_print(2, "NOsh:  Read non-float (%s) while parsing ION keyword!\n", tok);
+			return VRC_FAILURE;
+		}
+		thee->ionr[thee->nion] = tf;
+		
+	}else{
+		
+		/* Three key-value pairs (charge, radius and conc) */
+		for(i=0;i<keyValuePairs;i++){
+			
+			/* Now scan for the value (float) to be used with the key token parsed 
+			 * above the if-else statement */
+			VJMPERR1(Vio_scanf(sock, "%s", value) == 1);
+			if(!strcmp(tok,"charge")){
+				setCharge = sscanf(value, "%lf", &charge);
+				if (setCharge == 0){
+					Vnm_print(2,"NOsh:  Read non-float (%s) while parsing ION %s keyword!\n", value, tok);
+					return VRC_FAILURE;
+				}
+				thee->ionq[thee->nion] = charge;
+			}else if(!strcmp(tok,"radius")){
+				setRadius = sscanf(value, "%lf", &radius);
+				if (setRadius == 0){
+					Vnm_print(2,"NOsh:  Read non-float (%s) while parsing ION %s keyword!\n", value, tok);
+					return VRC_FAILURE;
+				}
+				thee->ionr[thee->nion] = radius;
+			}else if(!strcmp(tok,"conc")){
+				setConc = sscanf(value, "%lf", &conc);
+				if (setConc == 0){
+					Vnm_print(2,"NOsh:  Read non-float (%s) while parsing ION %s keyword!\n", value, tok);
+					return VRC_FAILURE;
+				}
+				thee->ionc[thee->nion] = conc;
+			}else{
+				Vnm_print(2,"NOsh:  Illegal or missing key-value pair for ION keyword!\n");
+				return VRC_FAILURE;
+			}
+			
+			/* If all three values haven't be set (setValue = 0) then read the next token */
+			if((setCharge != 1) || (setConc != 1) || (setRadius != 1)){
+				VJMPERR1(Vio_scanf(sock, "%s", tok) == 1);
+			}
+			
+		} /* end for */
+	} /* end if */
+	
+	/* Finally set the setion, nion and setnion flags and return success */
+	thee->setion[thee->nion] = 1;
+	(thee->nion)++;
+	thee->setnion = 1;
+	return VRC_SUCCESS;
+	
     VERROR1:
         Vnm_print(2, "parsePBE:  ran out of tokens!\n");
-        return -1;
+        return VRC_FAILURE;
 }
 
 VPRIVATE int PBEparm_parsePDIE(PBEparm *thee, Vio *sock) {
