@@ -3,7 +3,7 @@
  *  @ingroup Vacc
  *  @author  Nathan Baker
  *  @brief   Class Vacc methods
- *  @version $Id: vacc.c 1100 2007-06-25 17:02:52Z sobolevnrm $
+ *  @version $Id: vacc.c 1251 2008-03-30 22:32:00Z sobolevnrm $
  *  @attention
  *  @verbatim
  *
@@ -16,50 +16,38 @@
  *
  * Additional contributing authors listed in the code documentation.
  *
- * Copyright (c) 2002-2007.  Washington University in St. Louis.
- * All Rights Reserved.
- * Portions Copyright (c) 1999-2002.  The Regents of the University of
- * California.  
- * Portions Copyright (c) 1995.  Michael Holst.
+ * Copyright (c) 2002-2008, Washington University in St. Louis.
+ * Portions Copyright (c) 2002-2008.  Nathan A. Baker
+ * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
+ * Portions Copyright (c) 1995.  Michael Holst
  *
- * This file is part of APBS.
- *
- * APBS is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * APBS is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with APBS; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
- *
- * Linking APBS statically or dynamically with other modules is making a
- * combined work based on APBS. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
+ * All rights reserved.
  * 
- * SPECIAL GPL EXCEPTION
- * In addition, as a special exception, the copyright holders of APBS
- * give you permission to combine the APBS program with free software
- * programs and libraries that are released under the GNU LGPL or with
- * code included in releases of ISIM, Ion Simulator Interface, PMV, PyMOL
- * SMOL, VMD, and Vision. Such combined software may be linked with APBS and 
- * redistributed together in original or modified form as mere aggregation
- * without requirement that the entire work be under the scope of the GNU 
- * General Public License. This special exception permission is also extended
- * to any software listed in the SPECIAL GPL EXCEPTION clauses by the PMG,
- * FEtk, MC, or MALOC libraries.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met: 
+ *
+ * -  Redistributions of source code must retain the above copyright notice, this
+ * list of conditions and the following disclaimer.  
  * 
- * Note that people who make modified versions of APBS are not obligated
- * to grant this special exception for their modified versions; it is
- * their choice whether to do so. The GNU General Public License gives
- * permission to release a modified version without this exception; this
- * exception also makes it possible to release a modified version which
- * carries forward this exception.
+ * - Redistributions in binary form must reproduce the above copyright notice,
+ * this list of conditions and the following disclaimer in the documentation
+ * and/or other materials provided with the distribution.
+ * 
+ * - Neither the name of Washington University in St. Louis nor the names of its
+ * contributors may be used to endorse or promote products derived from this
+ * software without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
+ * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
+ * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+ * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+ * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * @endverbatim
  */
@@ -72,7 +60,7 @@
 #include "mc/mc.h"
 #endif
 
-VEMBED(rcsid="$Id: vacc.c 1100 2007-06-25 17:02:52Z sobolevnrm $")
+VEMBED(rcsid="$Id: vacc.c 1251 2008-03-30 22:32:00Z sobolevnrm $")
 
 #if !defined(VINLINE_VACC)
 
@@ -93,56 +81,52 @@ VPUBLIC unsigned long int Vacc_memChk(Vacc *thee) {
  * @author  Nathan Baker
  */
 VPRIVATE int ivdwAccExclus(
-        Vacc *thee,  /** Accessibility object */
-        double center[3],  /** Position to test */
-        double radius,  /** Radius of probe */ 
-        int atomID  /** ID of atom to ignore */
-        ) {
-
+						   Vacc *thee,  /** Accessibility object */
+						   double center[3],  /** Position to test */
+						   double radius,  /** Radius of probe */ 
+						   int atomID  /** ID of atom to ignore */
+						   ) {
+	
     int iatom;
     double dist2, *apos;
     Vatom *atom;
     VclistCell *cell;
-
+	
     VASSERT(thee != VNULL);
-
+	
     /* We can only test probes with radii less than the max specified */
     if (radius > Vclist_maxRadius(thee->clist)) {
         Vnm_print(2, 
-            "Vacc_ivdwAcc: got radius (%g) bigger than max radius (%g)\n", 
-            radius, Vclist_maxRadius(thee->clist));
-         VASSERT(0);
+				  "Vacc_ivdwAcc: got radius (%g) bigger than max radius (%g)\n", 
+				  radius, Vclist_maxRadius(thee->clist));
+		VASSERT(0);
     }
-
+	
     /* Get the relevant cell from the cell list */
     cell = Vclist_getCell(thee->clist, center);
-
+	
     /* If we have no cell, then no atoms are nearby and we're definitely
      * accessible */
     if (cell == VNULL) {
-        return 1.0;
+        return 1;
     }
-
+	
     /* Otherwise, check for overlap with the atoms in the cell */
     for (iatom=0; iatom<cell->natoms; iatom++) {
         atom = cell->atoms[iatom];
-        if (atom->id != atomID) {
-            apos = Vatom_getPosition(atom);
-            dist2 = VSQR(center[0]-apos[0]) + VSQR(center[1]-apos[1]) 
-                + VSQR(center[2]-apos[2]); 
-            if (dist2 < VSQR(Vatom_getRadius(atom)+radius)){
-				//printf("Dist2: %f %f\n",dist2,VSQR(Vatom_getRadius(atom)+radius));
-				return 0.0;
-			}
-        }
-    }
-
+		apos = atom->position;
+		dist2 = VSQR(center[0]-apos[0]) + VSQR(center[1]-apos[1]) 
+						+ VSQR(center[2]-apos[2]); 
+		if (dist2 < VSQR(atom->radius+radius)){
+			if (atom->id != atomID) return 0;			
+		}
+	}
+	
     /* If we're still here, then the point is accessible */
-    return 1.0;
-
+    return 1;
+	
 }
 
-
 VPUBLIC Vacc* Vacc_ctor(Valist *alist, Vclist *clist, double surf_density) {
 
 
@@ -1132,6 +1116,8 @@ VPUBLIC void Vacc_splineAccGradAtomNorm3(Vacc *thee, double center[VAPBS_DIM],
 VPUBLIC void Vacc_atomdSAV(Vacc *thee, double srad, Vatom *atom, double *dSA) { 
 	
     int ipt, iatom;
+
+    double area;
     double *tPos, tRad, vec[3];
     double dx,dy,dz;
     VaccSurf *ref;
@@ -1151,7 +1137,7 @@ VPUBLIC void Vacc_atomdSAV(Vacc *thee, double srad, Vatom *atom, double *dSA) {
 	
 	if(tRad == 0.0) return;
 	
-    double area = 4.0*VPI*(tRad+srad)*(tRad+srad)/((double)(ref->npts));
+    area = 4.0*VPI*(tRad+srad)*(tRad+srad)/((double)(ref->npts));
     for (ipt=0; ipt<ref->npts; ipt++) {
         vec[0] = (tRad+srad)*ref->xpts[ipt] + tPos[0];
         vec[1] = (tRad+srad)*ref->ypts[ipt] + tPos[1];
@@ -1217,7 +1203,7 @@ VPRIVATE double Vacc_atomSASAPos(Vacc *thee, double radius, Vatom *atom,int mode
     id = Vatom_getAtomID(atom);
     asurf = thee->surf[id];
 	
-	VaccSurf_dtor2(asurf);
+	VaccSurf_dtor(&asurf);
 	thee->surf[id] = Vacc_atomSurf(thee, atom, thee->refSphere, radius);
 	asurf = thee->surf[id];
 	
@@ -1495,6 +1481,11 @@ int Vacc_wcaEnergyAtom(Vacc *thee, APOLparm *apolparm, Valist *alist,
 	int npts[3];
 	int pad = 14;
 
+        int xmin, ymin, zmin;
+        int xmax, ymax, zmax;
+
+        double sigma6, sigma12;
+
 	double spacs[3], vec[3];
     double w, wx, wy, wz, len, fn, x, y, z, vol;
 	double x2,y2,z2,r;
@@ -1534,16 +1525,16 @@ int Vacc_wcaEnergyAtom(Vacc *thee, APOLparm *apolparm, Valist *alist,
     epsilon = VSQRT((epsilon * watepsilon));
 	
 	/* parameters */
-    double sigma6 = VPOW(sigma,6);
-    double sigma12 = VPOW(sigma,12);
+    sigma6 = VPOW(sigma,6);
+    sigma12 = VPOW(sigma,12);
     /* OPLS-style radius:  double sigmar = sigma*VPOW(2, (1.0/6.0)); */
 	
-	int xmin = pos[0] - pad;
-	int xmax = pos[0] + pad;
-	int ymin = pos[1] - pad;
-	int ymax = pos[1] + pad;
-	int zmin = pos[2] - pad;
-	int zmax = pos[2] + pad;
+	xmin = pos[0] - pad;
+	xmax = pos[0] + pad;
+	ymin = pos[1] - pad;
+	ymax = pos[1] + pad;
+	zmin = pos[2] - pad;
+	zmax = pos[2] + pad;
 	
 	for (i=0; i<3; i++) {
 		len = (upper_corner[i] + pad) - (lower_corner[i] - pad);
@@ -1621,7 +1612,7 @@ int Vacc_wcaEnergyAtom(Vacc *thee, APOLparm *apolparm, Valist *alist,
 	
 	*value = energy;
 
-	return 1;
+	return VRC_SUCCESS;
 }
 
 VPUBLIC int Vacc_wcaEnergy(Vacc *acc, APOLparm *apolparm, Valist *alist,
@@ -1634,6 +1625,13 @@ VPUBLIC int Vacc_wcaEnergy(Vacc *acc, APOLparm *apolparm, Valist *alist,
 	double tenergy = 0.0;
 	double rho = apolparm->bconc;
 	
+	/* Do a sanity check to make sure that watepsilon and watsigma are set
+	 * If not, return with an error. */
+	if(apolparm->setwat == 0){
+		Vnm_print(2,"Vacc_wcaEnergy: Error. No value was set for watsigma and watepsilon.\n");
+		return VRC_FAILURE;
+	}
+	
 	if (VABS(rho) < VSMALL) {
 		apolparm->wcaEnergy = tenergy;
 		return 1; 		
@@ -1644,12 +1642,11 @@ VPUBLIC int Vacc_wcaEnergy(Vacc *acc, APOLparm *apolparm, Valist *alist,
 		if(rc == 0) return 0;
 		
 		tenergy += energy;
-		Vnm_print(1,"wcaEnergy for atom %i: %1.12E\n",iatom,energy);
     }
 
 	apolparm->wcaEnergy = tenergy;
 	
-    return 1; 
+    return VRC_SUCCESS; 
 	
 }
 
@@ -1658,6 +1655,11 @@ VPUBLIC int Vacc_wcaForceAtom(Vacc *thee, APOLparm *apolparm, Vclist *clist,
 	int i,si;
 	int npts[3];
 	int pad = 14;
+
+        int xmin, ymin, zmin;
+        int xmax, ymax, zmax;
+
+        double sigma6, sigma12;
 	
 	double spacs[3], vec[3], fpt[3];
     double w, wx, wy, wz, len, fn, x, y, z, vol;
@@ -1671,6 +1673,13 @@ VPUBLIC int Vacc_wcaForceAtom(Vacc *thee, APOLparm *apolparm, Vclist *clist,
 
 	VASSERT(apolparm != VNULL);
 	
+	/* Do a sanity check to make sure that watepsilon and watsigma are set
+	 * If not, return with an error. */
+	if(apolparm->setwat == 0){
+		Vnm_print(2,"Vacc_wcaEnergy: Error. No value was set for watsigma and watepsilon.\n");
+		return VRC_FAILURE;
+	}
+	
 	vol = 1.0;
 	vol_density = 2.0;
 	
@@ -1696,8 +1705,8 @@ VPUBLIC int Vacc_wcaForceAtom(Vacc *thee, APOLparm *apolparm, Vclist *clist,
     epsilon = VSQRT((epsilon * watepsilon));
 		
 	/* parameters */
-    double sigma6 = VPOW(sigma,6);
-    double sigma12 = VPOW(sigma,12);
+    sigma6 = VPOW(sigma,6);
+    sigma12 = VPOW(sigma,12);
     /* OPLS-style radius:  double sigmar = sigma*VPOW(2, (1.0/6.0));  */
 	
 	for (i=0; i<3; i++) {
@@ -1715,13 +1724,13 @@ VPUBLIC int Vacc_wcaForceAtom(Vacc *thee, APOLparm *apolparm, Vclist *clist,
 			spacs[i] = apolparm->grid[i];
 		}
 	}
-	
-	int xmin = pos[0] - pad;
-	int xmax = pos[0] + pad;
-	int ymin = pos[1] - pad;
-	int ymax = pos[1] + pad;
-	int zmin = pos[2] - pad;
-	int zmax = pos[2] + pad;
+
+	xmin = pos[0] - pad;
+	xmax = pos[0] + pad;
+	ymin = pos[1] - pad;
+	ymax = pos[1] + pad;
+	zmin = pos[2] - pad;
+	zmax = pos[2] + pad;
 	
 	for (x=xmin; x<=xmax; x=x+spacs[0]) {
 		if ( VABS(x - xmin) < VSMALL) {
@@ -1788,6 +1797,6 @@ VPUBLIC int Vacc_wcaForceAtom(Vacc *thee, APOLparm *apolparm, Vclist *clist,
 	w  = spacs[0]*spacs[1]*spacs[2];
 	for(i=0;i<3;i++) force[i] *= w;
 
-	return 1;
+	return VRC_SUCCESS;
 }
 
