@@ -2,7 +2,7 @@
  *  @file    valist.c
  *  @author  Nathan Baker
  *  @brief   Class Valist methods
- *  @version $Id: valist.c 1083 2007-03-21 12:47:38Z sobolevnrm $
+ *  @version $Id: valist.c 1257 2008-04-09 19:12:56Z sdg0919 $
  *  @attention
  *  @verbatim
  *
@@ -15,50 +15,38 @@
  *
  * Additional contributing authors listed in the code documentation.
  *
- * Copyright (c) 2002-2007.  Washington University in St. Louis.
- * All Rights Reserved.
- * Portions Copyright (c) 1999-2002.  The Regents of the University of
- * California.  
- * Portions Copyright (c) 1995.  Michael Holst.
+ * Copyright (c) 2002-2008, Washington University in St. Louis.
+ * Portions Copyright (c) 2002-2008.  Nathan A. Baker
+ * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
+ * Portions Copyright (c) 1995.  Michael Holst
  *
- * This file is part of APBS.
- *
- * APBS is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * APBS is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with APBS; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
- *
- * Linking APBS statically or dynamically with other modules is making a
- * combined work based on APBS. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
+ * All rights reserved.
  * 
- * SPECIAL GPL EXCEPTION
- * In addition, as a special exception, the copyright holders of APBS
- * give you permission to combine the APBS program with free software
- * programs and libraries that are released under the GNU LGPL or with
- * code included in releases of ISIM, Ion Simulator Interface, PMV, PyMOL
- * SMOL, VMD, and Vision. Such combined software may be linked with APBS and 
- * redistributed together in original or modified form as mere aggregation
- * without requirement that the entire work be under the scope of the GNU 
- * General Public License. This special exception permission is also extended
- * to any software listed in the SPECIAL GPL EXCEPTION clauses by the PMG,
- * FEtk, MC, or MALOC libraries.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met: 
+ *
+ * -  Redistributions of source code must retain the above copyright notice, this
+ * list of conditions and the following disclaimer.  
  * 
- * Note that people who make modified versions of APBS are not obligated
- * to grant this special exception for their modified versions; it is
- * their choice whether to do so. The GNU General Public License gives
- * permission to release a modified version without this exception; this
- * exception also makes it possible to release a modified version which
- * carries forward this exception.
+ * - Redistributions in binary form must reproduce the above copyright notice,
+ * this list of conditions and the following disclaimer in the documentation
+ * and/or other materials provided with the distribution.
+ * 
+ * - Neither the name of Washington University in St. Louis nor the names of its
+ * contributors may be used to endorse or promote products derived from this
+ * software without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
+ * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
+ * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+ * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+ * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * @endverbatim
  */
@@ -66,7 +54,7 @@
 #include "apbscfg.h"
 #include "apbs/valist.h"
 
-VEMBED(rcsid="$Id: valist.c 1083 2007-03-21 12:47:38Z sobolevnrm $")
+VEMBED(rcsid="$Id: valist.c 1257 2008-04-09 19:12:56Z sdg0919 $")
 
 VPRIVATE char *Valist_whiteChars = " \t\n";
 VPRIVATE char *Valist_commChars  = "#%";
@@ -76,42 +64,63 @@ VPRIVATE char *Valist_xmlwhiteChars = " \t\n<>";
 
 VPUBLIC double Valist_getCenterX(Valist *thee) {
  
-    VASSERT(thee != NULL);
+    if (thee == NULL) {
+		Vnm_print(2, "Valist_getCenterX:  Found null pointer when getting the center of X coordinate!\n");
+		VASSERT(0);
+	}
     return thee->center[0];
 
 }
 
 VPUBLIC double Valist_getCenterY(Valist *thee) {
 
-    VASSERT(thee != NULL);
+    if (thee == NULL) {
+		Vnm_print(2, "Valist_getCenterY:  Found null pointer when getting the center of Y coordinate!\n");
+		VASSERT(0);
+	}
     return thee->center[1];
 
 }
 VPUBLIC double Valist_getCenterZ(Valist *thee) {
 
-    VASSERT(thee != NULL);
+    if (thee == NULL) {
+		Vnm_print(2, "Valist_getCenterZ:  Found null pointer when getting the center of Z coordinate!\n");
+		VASSERT(0);
+	}
     return thee->center[2];
 
 }
 
 VPUBLIC Vatom* Valist_getAtomList(Valist *thee) {
 
-    VASSERT(thee != NULL);
+    if (thee == NULL) {
+		Vnm_print(2, "Valist_getAtomList:  Found null pointer when getting the atom list!\n");
+		VASSERT(0);
+	}
     return thee->atoms;
 
 }
 
 VPUBLIC int Valist_getNumberAtoms(Valist *thee) {
 
-    VASSERT(thee != NULL);
+    if (thee == NULL) {
+		Vnm_print(2, "Valist_getNumberAtoms:  Found null pointer when getting the number of atoms!\n");
+		VASSERT(0);
+	}
     return thee->number;
 
 }
 
 VPUBLIC Vatom* Valist_getAtom(Valist *thee, int i) {
 
-    VASSERT(thee != NULL);
-    VASSERT(i < thee->number);
+    if (thee == NULL) {
+		Vnm_print(2, "Valist_getAtom:  Found null pointer when getting atoms!\n");
+		VASSERT(0);
+	}
+    if (i >= thee->number) {
+		Vnm_print(2, "Valist_getAtom:  Requested atom number (%d) outside of atom list range (%d)!\n", i, thee->number);
+		VASSERT(0);
+	}
     return &(thee->atoms[i]);
 
 }
@@ -130,13 +139,19 @@ VPUBLIC Valist* Valist_ctor() {
     /* Set up the structure */
     Valist *thee = VNULL;
     thee = Vmem_malloc(VNULL, 1, sizeof(Valist));
-    VASSERT( thee != VNULL);
-    VASSERT( Valist_ctor2(thee));
+    if ( thee == VNULL) {
+		Vnm_print(2, "Valist_ctor:  Got NULL pointer when constructing the atom list object!\n");
+		VASSERT(0);
+	}
+    if ( Valist_ctor2(thee) != VRC_SUCCESS) {
+		Vnm_print(2, "Valist_ctor:   Error in constructing the atom list object!\n");
+		VASSERT(0);
+	}
  
     return thee;
 }
 
-VPUBLIC int Valist_ctor2(Valist *thee) {
+VPUBLIC Vrc_Codes Valist_ctor2(Valist *thee) {
   
     thee->atoms = VNULL;
     thee->number = 0;
@@ -144,7 +159,7 @@ VPUBLIC int Valist_ctor2(Valist *thee) {
     /* Initialize the memory management object */
     thee->vmem = Vmem_ctor("APBS:VALIST");
 
-    return 1;    
+    return VRC_SUCCESS;    
 
 }
 
@@ -167,63 +182,63 @@ VPUBLIC void Valist_dtor2(Valist *thee) {
 } 
 
 /* Read serial number from PDB ATOM/HETATM field */
-VPRIVATE int Valist_readPDBSerial(Valist *thee, Vio *sock, int *serial) {
+VPRIVATE Vrc_Codes Valist_readPDBSerial(Valist *thee, Vio *sock, int *serial) {
 
     char tok[VMAX_BUFSIZE];
     int ti = 0;
 
     if (Vio_scanf(sock, "%s", tok) != 1) {
         Vnm_print(2, "Valist_readPDB:  Ran out of tokens while parsing serial!\n");
-        return 0;
+        return VRC_FAILURE;
     } 
     if (sscanf(tok, "%d", &ti) != 1) {
         Vnm_print(2, "Valist_readPDB:  Unable to parse serial token (%s) as int!\n",
                 tok);
-        return 0;
+        return VRC_FAILURE;
     } 
     *serial = ti;
 
-    return 1;
+    return VRC_SUCCESS;
 }
 
 /* Read atom name from PDB ATOM/HETATM field */
-VPRIVATE int Valist_readPDBAtomName(Valist *thee, Vio *sock, 
+VPRIVATE Vrc_Codes Valist_readPDBAtomName(Valist *thee, Vio *sock, 
         char atomName[VMAX_ARGLEN]) {
 
     char tok[VMAX_BUFSIZE];
 
     if (Vio_scanf(sock, "%s", tok) != 1) {
         Vnm_print(2, "Valist_readPDB:  Ran out of tokens while parsing atom name!\n");
-        return 0;
+        return VRC_FAILURE;
     }
     if (strlen(tok) < VMAX_ARGLEN) strcpy(atomName, tok);
     else {
         Vnm_print(2, "Valist_readPDB:  Atom name (%s) too long!\n", tok);
-        return 0;
+        return VRC_FAILURE;
     }
-    return 1;
+    return VRC_SUCCESS;
 }
 
 /* Read residue name from PDB ATOM/HETATM field */
-VPRIVATE int Valist_readPDBResidueName(Valist *thee, Vio *sock, 
+VPRIVATE Vrc_Codes Valist_readPDBResidueName(Valist *thee, Vio *sock, 
         char resName[VMAX_ARGLEN]) {
 
     char tok[VMAX_BUFSIZE];
 
     if (Vio_scanf(sock, "%s", tok) != 1) {
         Vnm_print(2, "Valist_readPDB:  Ran out of tokens while parsing residue name!\n");
-        return 0;
+        return VRC_FAILURE;
     }
     if (strlen(tok) < VMAX_ARGLEN) strcpy(resName, tok);
     else {
         Vnm_print(2, "Valist_readPDB:  Residue name (%s) too long!\n", tok);
-        return 0;
+        return VRC_FAILURE;
     }
-    return 1;
+    return VRC_SUCCESS;
 }
 
 /* Read residue number from PDB ATOM/HETATM field */
-VPRIVATE int Valist_readPDBResidueNumber(
+VPRIVATE Vrc_Codes Valist_readPDBResidueNumber(
         Valist *thee, Vio *sock, int *resSeq) {
 
     char tok[VMAX_BUFSIZE];
@@ -232,7 +247,7 @@ VPRIVATE int Valist_readPDBResidueNumber(
 
     if (Vio_scanf(sock, "%s", tok) != 1) {
         Vnm_print(2, "Valist_readPDB:  Ran out of tokens while parsing resSeq!\n");
-        return 0;
+        return VRC_FAILURE;
     } 
     if (sscanf(tok, "%d", &ti) != 1) {
 
@@ -249,54 +264,55 @@ VPRIVATE int Valist_readPDBResidueNumber(
 
 			if (Vio_scanf(sock, "%s", tok) != 1) {
         		Vnm_print(2, "Valist_readPDB:  Ran out of tokens while parsing resSeq!\n");
-        		return 0;
+        		return VRC_FAILURE;
     		}   
     		if (sscanf(tok, "%d", &ti) != 1) {
 				Vnm_print(2, "Valist_readPDB:  Unable to parse resSeq token (%s) as int!\n",
                 tok);
-        		return 0;
+        		return VRC_FAILURE;
 			}
 				
 		} else {
 			/* Case 2: Chain ID, merged string.
 					   Move pointer forward past the chainID and check
     	    */
-			strcpy(resstring, tok); 
+		    //strcpy(resstring, tok);
+			resstring = tok;
 			resstring++;
 
 			if (sscanf(resstring, "%d", &ti) != 1) {
 				/* Case 3:  More than one non-numeral char is present. Error.*/
                 Vnm_print(2, "Valist_readPDB:  Unable to parse resSeq token (%s) as int!\n",
                 resstring);
-            	return 0;
+            	return VRC_FAILURE;
 			}
 		} 
     } 
     *resSeq = ti;
 
-    return 1;
+    return VRC_SUCCESS;
 }
 
 /* Read atom coordinate from PDB ATOM/HETATM field */
-VPRIVATE int Valist_readPDBAtomCoord(Valist *thee, Vio *sock, double *coord) {
+VPRIVATE Vrc_Codes Valist_readPDBAtomCoord(Valist *thee, Vio *sock, double *coord) {
 
     char tok[VMAX_BUFSIZE];
     double tf = 0;
 
     if (Vio_scanf(sock, "%s", tok) != 1) {
         Vnm_print(2, "Valist_readPDB:  Ran out of tokens while parsing atom coordinate!\n");
-        return 0;
+        return VRC_FAILURE;
     } 
     if (sscanf(tok, "%lf", &tf) != 1) {
-        return 0;
+        return VRC_FAILURE;
     } 
     *coord = tf;
 
-    return 1;
+    return VRC_SUCCESS;
 }
 
 /* Read charge and radius from PQR ATOM/HETATM field */
-VPRIVATE int Valist_readPDBChargeRadius(Valist *thee, Vio *sock, 
+VPRIVATE Vrc_Codes Valist_readPDBChargeRadius(Valist *thee, Vio *sock, 
         double *charge, double *radius) {
 
     char tok[VMAX_BUFSIZE];
@@ -304,27 +320,27 @@ VPRIVATE int Valist_readPDBChargeRadius(Valist *thee, Vio *sock,
 
     if (Vio_scanf(sock, "%s", tok) != 1) {
         Vnm_print(2, "Valist_readPQR:  Ran out of tokens while parsing charge!\n");
-        return 0;
+        return VRC_FAILURE;
     } 
     if (sscanf(tok, "%lf", &tf) != 1) {
-        return 0;
+        return VRC_FAILURE;
     } 
     *charge = tf;
 
     if (Vio_scanf(sock, "%s", tok) != 1) {
         Vnm_print(2, "Valist_readPQR:  Ran out of tokens while parsing radius!\n");
-        return 0;
+        return VRC_FAILURE;
     } 
     if (sscanf(tok, "%lf", &tf) != 1) {
-        return 0;
+        return VRC_FAILURE;
     } 
     *radius = tf;
 
-    return 1;
+    return VRC_SUCCESS;
 }
 
 /* Read ATOM/HETATM field of PDB through the X/Y/Z fields */
-VPRIVATE int Valist_readPDB_throughXYZ(
+VPRIVATE Vrc_Codes Valist_readPDB_throughXYZ(
         Valist *thee, 
         Vio *sock, /* Socket ready for reading */
         int *serial, /* Set to atom number */
@@ -340,27 +356,27 @@ VPRIVATE int Valist_readPDB_throughXYZ(
     int i, njunk, gotit;
 
     /* Grab serial */
-    if (!Valist_readPDBSerial(thee, sock, serial)) {
+    if (Valist_readPDBSerial(thee, sock, serial) == VRC_FAILURE) {
         Vnm_print(2, "Valist_readPDB:  Error while parsing serial!\n");
     }
 
     /* Grab atom name */
-    if (!Valist_readPDBAtomName(thee, sock, atomName)) {
+    if (Valist_readPDBAtomName(thee, sock, atomName) == VRC_FAILURE) {
         Vnm_print(2, "Valist_readPDB:  Error while parsing atom name!\n");
-        return 0;
+        return VRC_FAILURE;
     }
 
     /* Grab residue name */
-    if (!Valist_readPDBResidueName(thee, sock, resName)) {
+    if (Valist_readPDBResidueName(thee, sock, resName) == VRC_FAILURE) {
         Vnm_print(2, "Valist_readPDB:  Error while parsing residue name!\n");
-        return 0;
+        return VRC_FAILURE;
     }
 
 
     /* Grab residue number */
-    if (!Valist_readPDBResidueNumber(thee, sock, resSeq)) {
+    if (Valist_readPDBResidueNumber(thee, sock, resSeq) == VRC_FAILURE) {
         Vnm_print(2, "Valist_readPDB:  Error while parsing residue name!\n");
-        return 0;
+        return VRC_FAILURE;
     }
 
 
@@ -370,24 +386,24 @@ VPRIVATE int Valist_readPDB_throughXYZ(
     njunk = 1;
     gotit = 0;
     for (i=0; i<(njunk+1); i++) {
-        if (Valist_readPDBAtomCoord(thee, sock, x)) {
+        if (Valist_readPDBAtomCoord(thee, sock, x) == VRC_SUCCESS) {
             gotit = 1;
             break;
         }
     }
     if (!gotit) {
         Vnm_print(2, "Valist_readPDB:  Can't find x!\n");
-        return 0;
+        return VRC_FAILURE;
     }
     /* Read y-coordinate */
-    if (!Valist_readPDBAtomCoord(thee, sock, y)) {
+    if (Valist_readPDBAtomCoord(thee, sock, y) == VRC_FAILURE) {
         Vnm_print(2, "Valist_readPDB:  Can't find y!\n");
-        return 0;
+        return VRC_FAILURE;
     }
     /* Read z-coordinate */
-    if (!Valist_readPDBAtomCoord(thee, sock, z)) {
+    if (Valist_readPDBAtomCoord(thee, sock, z) == VRC_FAILURE) {
         Vnm_print(2, "Valist_readPDB:  Can't find z!\n");
-        return 0;
+        return VRC_FAILURE;
     }
 
 #if 0 /* Set to 1 if you want to debug */
@@ -399,7 +415,7 @@ VPRIVATE int Valist_readPDB_throughXYZ(
               *x, *y, *z);
 #endif
 
-    return 1;
+    return VRC_SUCCESS;
 }
 
 /* Get a the next available atom storage location, increasing the storage
@@ -460,7 +476,7 @@ VPRIVATE Vatom* Valist_getAtomStorage(
     return newAtom;
 }
 
-VPRIVATE int Valist_setAtomArray(Valist *thee, 
+VPRIVATE Vrc_Codes Valist_setAtomArray(Valist *thee, 
         Vatom **plist, /* Pointer to list of atoms to store */
         int nlist, /* Length of list */
         int natoms /* Number of real atom entries in list */
@@ -477,7 +493,7 @@ VPRIVATE int Valist_setAtomArray(Valist *thee,
     if (thee->atoms == VNULL) {
         Vnm_print(2, "Valist_readPDB:  Unable to allocate space for %d (Vatom)s!\n", 
                 natoms);
-        return 0;
+        return VRC_FAILURE;
     }
     thee->number = natoms;
 
@@ -492,10 +508,10 @@ VPRIVATE int Valist_setAtomArray(Valist *thee,
     /* Free old array */
     Vmem_free(thee->vmem, nlist, sizeof(Vatom), (void **)plist);
 
-    return 1;
+    return VRC_SUCCESS;
 }
 
-VPUBLIC int Valist_readPDB(Valist *thee, Vparam *param, Vio *sock) {
+VPUBLIC Vrc_Codes Valist_readPDB(Valist *thee, Vparam *param, Vio *sock) {
 
     /* WE DO NOT DIRECTLY CONFORM TO PDB STANDARDS -- TO ALLOW LARGER FILES, WE
      * REQUIRE ALL FIELDS TO BE WHITESPACE DELIMITED */
@@ -512,7 +528,10 @@ VPUBLIC int Valist_readPDB(Valist *thee, Vparam *param, Vio *sock) {
 	double x, y, z, charge, radius, epsilon;
     double pos[3];
  
-    VASSERT(thee != VNULL);
+    if (thee == VNULL) {
+		Vnm_print(2, "Valist_readPDB:  Got NULL pointer when reading PDB file!\n");
+		VASSERT(0);
+	}
     thee->number = 0;
 
     Vio_setWhiteChars(sock, Valist_whiteChars);
@@ -531,11 +550,11 @@ VPUBLIC int Valist_readPDB(Valist *thee, Vparam *param, Vio *sock) {
             (Vstring_strcasecmp(tok, "HETATM") == 0)) {
 
             /* Read ATOM/HETATM field of PDB through the X/Y/Z fields */
-            if (!Valist_readPDB_throughXYZ(thee, sock, &serial, atomName, 
-                        resName, &resSeq, &x, &y, &z)) {
+            if (Valist_readPDB_throughXYZ(thee, sock, &serial, atomName, 
+                        resName, &resSeq, &x, &y, &z) == VRC_FAILURE) {
                 Vnm_print(2, "Valist_readPDB:  Error parsing atom %d!\n", 
                           serial);
-                return 0;
+                return VRC_FAILURE;
             }
 
             /* Try to find the parameters. */
@@ -543,7 +562,7 @@ VPUBLIC int Valist_readPDB(Valist *thee, Vparam *param, Vio *sock) {
             if (atomData == VNULL) {
                 Vnm_print(2, "Valist_readPDB:  Couldn't find parameters for \
 atom = %s, residue = %s\n", atomName, resName);
-                return 0;
+                return VRC_FAILURE;
             }
             charge = atomData->charge;
             radius = atomData->radius;
@@ -553,7 +572,7 @@ atom = %s, residue = %s\n", atomName, resName);
             nextAtom = Valist_getAtomStorage(thee, &atoms, &nlist, &natoms);
             if (nextAtom == VNULL) {
                 Vnm_print(2, "Valist_readPDB:  Error in allocating spacing for atoms!\n");
-                return 0;
+                return VRC_FAILURE;
             }
 
             /* Store the information */
@@ -573,9 +592,9 @@ atom = %s, residue = %s\n", atomName, resName);
     fflush(stdout);
 
     /* Store atoms internally */
-    if (!Valist_setAtomArray(thee, &atoms, nlist, natoms)) {
+    if (Valist_setAtomArray(thee, &atoms, nlist, natoms) == VRC_FAILURE) {
         Vnm_print(2, "Valist_readPDB:  unable to store atoms!\n");
-        return 0;
+        return VRC_FAILURE;
     }
 
     return Valist_getStatistics(thee);
@@ -583,7 +602,7 @@ atom = %s, residue = %s\n", atomName, resName);
 
 }
 
-VPUBLIC int Valist_readPQR(Valist *thee, Vparam *params, Vio *sock) {
+VPUBLIC Vrc_Codes Valist_readPQR(Valist *thee, Vparam *params, Vio *sock) {
 
     /* WE DO NOT DIRECTLY CONFORM TO PDB STANDARDS -- TO ALLOW LARGER FILES, WE
      * REQUIRE ALL FIELDS TO BE WHITESPACE DELIMITED */
@@ -602,7 +621,10 @@ VPUBLIC int Valist_readPQR(Valist *thee, Vparam *params, Vio *sock) {
     double x, y, z, charge, radius, epsilon;
     double pos[3];
  
-    VASSERT(thee != VNULL);
+    if (thee == VNULL) {
+		Vnm_print(2, "Valist_readPQR:  Got NULL pointer when reading PQR file!\n");
+		VASSERT(0);
+	}
     thee->number = 0;
 
     Vio_setWhiteChars(sock, Valist_whiteChars);
@@ -624,17 +646,17 @@ VPUBLIC int Valist_readPQR(Valist *thee, Vparam *params, Vio *sock) {
             (Vstring_strcasecmp(tok, "HETATM") == 0)) {
 
             /* Read ATOM/HETATM field of PDB through the X/Y/Z fields */
-            if (!Valist_readPDB_throughXYZ(thee, sock, &serial, atomName, 
-                        resName, &resSeq, &x, &y, &z)) {
+            if (Valist_readPDB_throughXYZ(thee, sock, &serial, atomName, 
+                        resName, &resSeq, &x, &y, &z) == VRC_FAILURE) {
                 Vnm_print(2, "Valist_readPQR:  Error parsing atom %d!\n",serial);
-                return 0;
+                return VRC_FAILURE;
             }
 
             /* Read Q/R fields */
-            if (!Valist_readPDBChargeRadius(thee, sock, &charge, &radius)) {
+            if (Valist_readPDBChargeRadius(thee, sock, &charge, &radius) == VRC_FAILURE) {
                 Vnm_print(2, "Valist_readPQR:  Error parsing atom %d!\n", 
                           serial);
-                return 0;
+                return VRC_FAILURE;
             }
 
 			if(use_params){
@@ -643,7 +665,7 @@ VPUBLIC int Valist_readPQR(Valist *thee, Vparam *params, Vio *sock) {
 				if (atomData == VNULL) {
 					Vnm_print(2, "Valist_readPDB:  Couldn't find parameters for \
 atom = %s, residue = %s\n", atomName, resName);
-					return 0;
+					return VRC_FAILURE;
 				}
 				charge = atomData->charge;
 				radius = atomData->radius;
@@ -654,7 +676,7 @@ atom = %s, residue = %s\n", atomName, resName);
             nextAtom = Valist_getAtomStorage(thee, &atoms, &nlist, &natoms);
             if (nextAtom == VNULL) {
                 Vnm_print(2, "Valist_readPQR:  Error in allocating spacing for atoms!\n");
-                return 0;
+                return VRC_FAILURE;
             }
 
             /* Store the information */
@@ -674,9 +696,9 @@ atom = %s, residue = %s\n", atomName, resName);
     fflush(stdout);
 
     /* Store atoms internally */
-    if (!Valist_setAtomArray(thee, &atoms, nlist, natoms)) {
+    if (Valist_setAtomArray(thee, &atoms, nlist, natoms) == VRC_FAILURE) {
         Vnm_print(2, "Valist_readPDB:  unable to store atoms!\n");
-        return 0;
+        return VRC_FAILURE;
     }
 
     return Valist_getStatistics(thee);
@@ -684,7 +706,7 @@ atom = %s, residue = %s\n", atomName, resName);
 
 }
 
-VPUBLIC int Valist_readXML(Valist *thee, Vparam *params, Vio *sock) {
+VPUBLIC Vrc_Codes Valist_readXML(Valist *thee, Vparam *params, Vio *sock) {
 
     Vatom *atoms = VNULL;
     Vatom *nextAtom = VNULL;
@@ -698,7 +720,10 @@ VPUBLIC int Valist_readXML(Valist *thee, Vparam *params, Vio *sock) {
 	double x, y, z, charge, radius, dtmp;
     double pos[3];
  
-    VASSERT(thee != VNULL);
+    if (thee == VNULL) {
+		Vnm_print(2, "Valist_readXML:  Got NULL pointer when reading XML file!\n");
+		VASSERT(0);
+	}
     thee->number = 0;
 
     Vio_setWhiteChars(sock, Valist_xmlwhiteChars);
@@ -735,7 +760,7 @@ VPUBLIC int Valist_readXML(Valist *thee, Vparam *params, Vio *sock) {
             if (sscanf(tok, "%lf", &dtmp) != 1) {
                 Vnm_print(2, "Valist_readXML:  Unexpected token (%s) while \
 reading x!\n", tok);
-                  return 0;
+                  return VRC_FAILURE;
               }
             x = dtmp;
             xset = 1;
@@ -744,7 +769,7 @@ reading x!\n", tok);
             if (sscanf(tok, "%lf", &dtmp) != 1) {
                 Vnm_print(2, "Valist_readXML:  Unexpected token (%s) while \
 reading y!\n", tok);
-                  return 0;
+                  return VRC_FAILURE;
               }
             y = dtmp;
             yset = 1;
@@ -753,7 +778,7 @@ reading y!\n", tok);
             if (sscanf(tok, "%lf", &dtmp) != 1) {
                 Vnm_print(2, "Valist_readXML:  Unexpected token (%s) while \
 reading z!\n", tok);
-                  return 0;
+                  return VRC_FAILURE;
               }
             z = dtmp;
             zset = 1;
@@ -762,7 +787,7 @@ reading z!\n", tok);
             if (sscanf(tok, "%lf", &dtmp) != 1) {
                 Vnm_print(2, "Valist_readXML:  Unexpected token (%s) while \
 reading charge!\n", tok);
-                  return 0;
+                  return VRC_FAILURE;
               }
             charge = dtmp;
             chgset = 1;
@@ -771,7 +796,7 @@ reading charge!\n", tok);
             if (sscanf(tok, "%lf", &dtmp) != 1) {
                 Vnm_print(2, "Valist_readXML:  Unexpected token (%s) while \
 reading radius!\n", tok);
-                  return 0;
+                  return VRC_FAILURE;
               }
             radius = dtmp;
             radset = 1;
@@ -781,7 +806,7 @@ reading radius!\n", tok);
             nextAtom = Valist_getAtomStorage(thee, &atoms, &nlist, &natoms);
             if (nextAtom == VNULL) {
                 Vnm_print(2, "Valist_readXML:  Error in allocating spacing for atoms!\n");
-                return 0;
+                return VRC_FAILURE;
             }
 
             if (xset && yset && zset && chgset && radset){
@@ -806,7 +831,7 @@ reading radius!\n", tok);
                 if (!zset) Vnm_print(2,"\tz value not set!\n"); 
                 if (!chgset) Vnm_print(2,"\tcharge value not set!\n"); 
                 if (!radset) Vnm_print(2,"\tradius value not set!\n"); 
-                return 0;
+                return VRC_FAILURE;
             }
         } else if (Vstring_strcasecmp(tok, endtag) == 0) break;
     }
@@ -815,9 +840,9 @@ reading radius!\n", tok);
     fflush(stdout);
 
     /* Store atoms internally */
-    if (!Valist_setAtomArray(thee, &atoms, nlist, natoms)) {
+    if (Valist_setAtomArray(thee, &atoms, nlist, natoms) == VRC_FAILURE) {
         Vnm_print(2, "Valist_readXML:  unable to store atoms!\n");
-        return 0;
+        return VRC_FAILURE;
     }
 
     return Valist_getStatistics(thee);
@@ -825,12 +850,15 @@ reading radius!\n", tok);
 }
 
 /* Load up Valist with various statistics */
-VPUBLIC int Valist_getStatistics(Valist *thee) {
+VPUBLIC Vrc_Codes Valist_getStatistics(Valist *thee) {
 
     Vatom *atom;
     int i, j;
 
-    VASSERT(thee != VNULL);
+    if (thee == VNULL) {
+		Vnm_print(2, "Valist_getStatistics:  Got NULL pointer when loading up Valist with various statistics!\n");
+		VASSERT(0);
+	}
 
     thee->center[0] = 0.;
     thee->center[1] = 0.;
@@ -838,7 +866,7 @@ VPUBLIC int Valist_getStatistics(Valist *thee) {
     thee->maxrad = 0.;
     thee->charge = 0.;
 
-    if (thee->number == 0) return 0;
+    if (thee->number == 0) return VRC_FAILURE;
 
     /* Reset stat variables */
     atom = &(thee->atoms[0]);
@@ -872,5 +900,5 @@ VPUBLIC int Valist_getStatistics(Valist *thee) {
 	Vnm_print(0, "Valist_getStatistics:  Molecule center:  (%g, %g, %g)\n",
 			  thee->center[0], thee->center[1], thee->center[2]);
 	
-    return 1;
+    return VRC_SUCCESS;
 }
