@@ -3,7 +3,7 @@
  *  @ingroup Vpmg
  *  @author  Nathan Baker
  *  @brief   Class Vpmg private method declaration
- *  @version $Id: vpmg-private.h 1092 2007-04-27 15:05:41Z sdg0919 $
+ *  @version $Id: vpmg-private.h 1251 2008-03-30 22:32:00Z sobolevnrm $
  *  @attention
  *  @verbatim
  *
@@ -16,50 +16,38 @@
  *
  * Additional contributing authors listed in the code documentation.
  *
- * Copyright (c) 2002-2006.  Washington University in St. Louis.
- * All Rights Reserved.
- * Portions Copyright (c) 1999-2002.  The Regents of the University of
- * California.  
- * Portions Copyright (c) 1995.  Michael Holst.
+ * Copyright (c) 2002-2008, Washington University in St. Louis.
+ * Portions Copyright (c) 2002-2008.  Nathan A. Baker
+ * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
+ * Portions Copyright (c) 1995.  Michael Holst
  *
- * This file is part of APBS.
- *
- * APBS is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * APBS is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with APBS; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
- *
- * Linking APBS statically or dynamically with other modules is making a
- * combined work based on APBS. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
+ * All rights reserved.
  * 
- * SPECIAL GPL EXCEPTION
- * In addition, as a special exception, the copyright holders of APBS
- * give you permission to combine the APBS program with free software
- * programs and libraries that are released under the GNU LGPL or with
- * code included in releases of ISIM, Ion Simulator Interface, PMV, PyMOL
- * SMOL, VMD, and Vision. Such combined software may be linked with APBS and 
- * redistributed together in original or modified form as mere aggregation
- * without requirement that the entire work be under the scope of the GNU 
- * General Public License. This special exception permission is also extended
- * to any software listed in the SPECIAL GPL EXCEPTION clauses by the PMG,
- * FEtk, MC, or MALOC libraries.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met: 
+ *
+ * -  Redistributions of source code must retain the above copyright notice, this
+ * list of conditions and the following disclaimer.  
  * 
- * Note that people who make modified versions of APBS are not obligated
- * to grant this special exception for their modified versions; it is
- * their choice whether to do so. The GNU General Public License gives
- * permission to release a modified version without this exception; this
- * exception also makes it possible to release a modified version which
- * carries forward this exception.
+ * - Redistributions in binary form must reproduce the above copyright notice,
+ * this list of conditions and the following disclaimer in the documentation
+ * and/or other materials provided with the distribution.
+ * 
+ * - Neither the name of Washington University in St. Louis nor the names of its
+ * contributors may be used to endorse or promote products derived from this
+ * software without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
+ * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
+ * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+ * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+ * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * @endverbatim
  */
@@ -561,6 +549,12 @@ VEXTERNC void F77MGSZ(int *mgcoar, int *mgdisc, int *mgsolv, int *nx, int *ny,
   int *narr, int *narrc, int *n_rpc, int *n_iz, int *n_ipc, int *nrwk, 
   int *niwk);
 
+#define F77MGSZAQUA VF77_MANGLE(mgszaqua, MGSZAQUA)
+VEXTERNC void F77MGSZAQUA(int *mgcoar, int *mgdisc, int *mgsolv, int *nx, int *ny,
+					  int *nz, int *nlev, int *nxc, int *nyc, int *nyz, int *nf, int *nc, 
+					  int *narr, int *narrc, int *n_rpc, int *n_iz, int *n_ipc, int *nrwk, 
+					  int *niwk);
+
 #define F77PACKMG VF77_MANGLE(packmg, PACKMG)
 VEXTERNC void F77PACKMG(int *iparm, double *rparm, int *nrwk, int *niwk,
   int *nx, int *ny, int *nz, int *nlev, int *nu1, int *nu2, int *mgkey, 
@@ -616,6 +610,20 @@ VEXTERNC void F77NRICHDRIV(int *iparm, double *rparm, int *iwork, double *rwork,
   double *gzcf, double *a1cf, double *a2cf, double *a3cf, double *ccf,
   double *fcf, double *tcf);
 
+/* TEMPORARY USEAQUA */
+#define F77CGMGDRIVAQUA VF77_MANGLE(cgmgdrivaqua, CGMGDRIVAQUA)
+VEXTERNC void F77CGMGDRIVAQUA(int *iparm, double *rparm, int *iwork, double *rwork,
+  double *u, double *xf, double *yf, double *zf, double *gxcf, double *gycf,
+  double *gzcf, double *a1cf, double *a2cf, double *a3cf, double *ccf,
+  double *fcf);
+
+/* TEMPORARY USEAQUA */
+#define F77NEWDRIVAQUA    VF77_MANGLE(newdrivaqua, NEWDRIVAQUA)
+VEXTERNC void F77NEWDRIVAQUA(int *iparm, double *rparm, int *iwork, double *rwork,
+  double *u, double *xf, double *yf, double *zf, double *gxcf, double *gycf,
+  double *gzcf, double *a1cf, double *a2cf, double *a3cf, double *ccf,
+  double *fcf);
+
 #define F77TSECND     VF77_MANGLE(tsecnd, TSECND)
 #define F77VPMGANORM  VF77_MANGLE(vpmganorm, VPMGANORM)
 #define F77VPMGABAND  VF77_MANGLE(vpmgaband, VPMGABAND)
@@ -624,9 +632,15 @@ VEXTERNC void F77NRICHDRIV(int *iparm, double *rparm, int *iwork, double *rwork,
 #define F77EIGDRIV    VF77_MANGLE(eigdriv, EIGDRIV)
 #define F77ANORMDRIV  VF77_MANGLE(anormdriv, ANORMDRIV)
 
-#define F77MYPDEFINIT VF77_MANGLE(mypdefinit, MYPDEFINIT)
-VEXTERNC void F77MYPDEFINIT(int *nion, double *ionQ, double *ionConc,
-							int *pbeType,double *smvolume,double *smsize);
+#define F77MYPDEFINITLPBE VF77_MANGLE(mypdefinitlpbe, MYPDEFINITLPBE)
+VEXTERNC void F77MYPDEFINITLPBE(int *nion, double *ionQ, double *ionConc);
+
+#define F77MYPDEFINITNPBE VF77_MANGLE(mypdefinitnpbe, MYPDEFINITNPBE)
+VEXTERNC void F77MYPDEFINITNPBE(int *nion, double *ionQ, double *ionConc);
+
+#define F77MYPDEFINITSMPBE VF77_MANGLE(mypdefinitsmpbe, MYPDEFINITSMPBE)
+VEXTERNC void F77MYPDEFINITSMPBE(int *nion, double *ionQ, double *ionConc,
+									double *smvolume,double *smsize);
 
 #define F77MYPDEFCLEAR VF77_MANGLE(mypdefclear, MYPDEFCLEAR)
 VEXTERNC void F77MYPDEFCLEAR();
