@@ -6,61 +6,50 @@
 
         ----------------------------
 
-    Version:  $Id: inputgen.py 1094 2007-05-25 21:53:54Z sobolevnrm $
+    Version:  $Id: inputgen.py 1251 2008-03-30 22:32:00Z sobolevnrm $
    
-    APBS -- Adaptive Poisson-Boltzmann Solver
-   
-    Nathan A. Baker (baker@biochem.wustl.edu)
-    Dept. of Biochemistry and Molecular Biophysics
-    Center for Computational Biology
-    Washington University in St. Louis
+	APBS -- Adaptive Poisson-Boltzmann Solver
 
-    Additional contributing authors listed in the code documentation.
+	  Nathan A. Baker (baker@biochem.wustl.edu)
+	  Dept. Biochemistry and Molecular Biophysics
+	  Center for Computational Biology
+	  Washington University in St. Louis
 
-    Copyright (c) 2002-2007.  Washington University in St. Louis.
-    All Rights Reserved.
-    Portions Copyright (c) 1999-2002.  The Regents of the University of
-    California.
-    Portions Copyright (c) 1995.  Michael Holst.
+	  Additional contributing authors listed in the code documentation.
 
-    This file is part of APBS.
+	Copyright (c) 2002-2008, Washington University in St. Louis.
+	Portions Copyright (c) 2002-2008.  Nathan A. Baker
+	Portions Copyright (c) 1999-2002.  The Regents of the University of California.
+	Portions Copyright (c) 1995.  Michael Holst
+
+	All rights reserved.
+
+	Redistribution and use in source and binary forms, with or without
+	modification, are permitted provided that the following conditions are met: 
+
+	* Redistributions of source code must retain the above copyright notice, this
+	list of conditions and the following disclaimer.  
+
+	* Redistributions in binary form must reproduce the above copyright notice,
+	this list of conditions and the following disclaimer in the documentation
+	and/or other materials provided with the distribution.
+
+	* Neither the name of Washington University in St. Louis nor the names of its
+	contributors may be used to endorse or promote products derived from this
+	software without specific prior written permission.
+
+	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+	"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+	LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+	A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
+	CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+	EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+	PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+	PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
+	LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+	NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+	SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-    APBS is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
- 
-    APBS is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-   
-    You should have received a copy of the GNU General Public License
-    along with PDB2PQR; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
- 
-    Linking APBS statically or dynamically with other modules is making a
-    combined work based on APBS. Thus, the terms and conditions of the GNU
-    General Public License cover the whole combination.
- 
-    SPECIAL GPL EXCEPTION
-    In addition, as a special exception, the copyright holders of APBS
-    give you permission to combine the APBS program with free software
-    programs and libraries that are released under the GNU LGPL or with
-    code included in releases of ISIM, Ion Simulator Interface, PMV, PyMOL
-    SMOL, VMD, and Vision. Such combined software may be linked with APBS and 
-    redistributed together in original or modified form as mere aggregation
-    without requirement that the entire work be under the scope of the GNU 
-    General Public License. This special exception permission is also extended
-    to any software listed in the SPECIAL GPL EXCEPTION clauses by the PMG,
-    FEtk, MC, or MALOC libraries.
-    
-    Note that people who make modified versions of APBS are not obligated
-    to grant this special exception for their modified versions; it is
-    their choice whether to do so. The GNU General Public License gives
-    permission to release a modified version without this exception; this
-    exception also makes it possible to release a modified version which
-    carries forward this exception.
 
     ----------------------------
 """
